@@ -5,6 +5,9 @@ package addrs
 
 import (
 	"strings"
+
+	"github.com/hashicorp/hcl/v2"
+	"github.com/hashicorp/terraform/internal/tfdiags"
 )
 
 // Module is an address for a module call within configuration. This is
@@ -66,6 +69,14 @@ func (m Module) Equal(other Module) bool {
 	return true
 }
 
+type moduleKey string
+
+func (m Module) UniqueKey() UniqueKey {
+	return moduleKey(m.String())
+}
+
+func (mk moduleKey) uniqueKeySigil() {}
+
 func (m Module) targetableSigil() {
 	// Module is targetable
 }
@@ -168,3 +179,101 @@ func (m Module) Ancestors() []Module {
 func (m Module) configMoveableSigil() {
 	// ModuleInstance is moveable
 }
+
+// parseModulePrefix attempts to parse the given traversal as an unkeyed module
+// address, suffixed by an arbitrary (but valid) address remainder, which is
+// also returned.
+//
+// Error diagnostics are returned if parsing according to the above conditions
+// fails: in particular if the traversal represents a keyed module instance
+// address rather than an unkeyed module.
+func parseModulePrefix(traversal hcl.Traversal) (Module, hcl.Traversal, tfdiags.Diagnostics) {
+	remain := traversal
+	var mod Module
+	var diags tfdiags.Diagnostics
+
+LOOP:
+	for len(remain) > 0 {
+		var next string
+		switch tt := remain[0].(type) {
+		case hcl.TraverseRoot:
+			next = tt.Name
+		case hcl.TraverseAttr:
+			next = tt.Name
+		default:
+			diags = diags.Append(&hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Invalid address operator",
+				Detail:   "Module address prefix must be followed by dot and then a name.",
+				Subject:  remain[0].SourceRange().Ptr(),
+			})
+			break LOOP
+		}
+
+		if next != "module" {
+			break
+		}
+
+		kwRange := remain[0].SourceRange()
+		remain = remain[1:]
+		// If we have the prefix "module" then we should be followed by an
+		// module call name, as an attribute.
+		if len(remain) == 0 {
+			diags = diags.Append(&hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Invalid address operator",
+				Detail:   "Prefix \"module.\" must be followed by a module name.",
+				Subject:  &kwRange,
+			})
+			break
+		}
+
+		var moduleName string
+		switch tt := remain[0].(type) {
+		case hcl.TraverseAttr:
+			moduleName = tt.Name
+		default:
+			diags = diags.Append(&hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Invalid address operator",
+				Detail:   "Prefix \"module.\" must be followed by a module name.",
+				Subject:  remain[0].SourceRange().Ptr(),
+			})
+			break LOOP
+		}
+		remain = remain[1:]
+
+		if len(remain) > 0 {
+			if _, ok := remain[0].(hcl.TraverseIndex); ok {
+				// Then we have a module instance key, which is invalid
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Module instance keys not allowed",
+					Detail:   "Module address must be a module (e.g. \"module.foo\"), not a module instance (e.g. \"module.foo[1]\").",
+					Subject:  remain[0].SourceRange().Ptr(),
+				})
+				break LOOP
+			}
+		}
+
+		mod = append(mod, moduleName)
+	}
+
+	var retRemain hcl.Traversal
+	if len(remain) > 0 {
+		retRemain = make(hcl.Traversal, len(remain))
+		copy(retRemain, remain)
+		// The first element here might be either a TraverseRoot or a
+		// TraverseAttr, depending on whether we had a module address on the
+		// front. To make life easier for callers, we'll normalize to always
+		// start with a TraverseRoot.
+		if tt, ok := retRemain[0].(hcl.TraverseAttr); ok {
+			retRemain[0] = hcl.TraverseRoot{
+				Name:     tt.Name,
+				SrcRange: tt.SrcRange,
+			}
+		}
+	}
+
+	return mod, retRemain, diags
+}
