@@ -84,14 +84,14 @@ func TestModuleInstanceEqual_false(t *testing.T) {
 func BenchmarkStringShort(b *testing.B) {
 	addr, _ := ParseModuleInstanceStr(`module.foo`)
 	for n := 0; n < b.N; n++ {
-		addr.String()
+		_ = addr.String()
 	}
 }
 
 func BenchmarkStringLong(b *testing.B) {
 	addr, _ := ParseModuleInstanceStr(`module.southamerica-brazil-region.module.user-regional-desktops.module.user-name`)
 	for n := 0; n < b.N; n++ {
-		addr.String()
+		_ = addr.String()
 	}
 }
 
@@ -164,6 +164,47 @@ func TestModuleInstance_IsDeclaredByCall(t *testing.T) {
 	}
 }
 
+func TestModuleInstance_ContainingModule(t *testing.T) {
+	tcs := map[string]struct {
+		module   string
+		expected string
+	}{
+		"no_instances": {
+			module:   "module.parent.module.child",
+			expected: "module.parent.module.child",
+		},
+		"last_instance": {
+			module:   "module.parent.module.child[0]",
+			expected: "module.parent.module.child",
+		},
+		"middle_instance": {
+			module:   "module.parent[0].module.child",
+			expected: "module.parent[0].module.child",
+		},
+		"all_instances": {
+			module:   "module.parent[0].module.child[0]",
+			expected: "module.parent[0].module.child",
+		},
+		"single_no_instance": {
+			module:   "module.parent",
+			expected: "module.parent",
+		},
+		"single_instance": {
+			module:   "module.parent[0]",
+			expected: "module.parent",
+		},
+	}
+	for name, tc := range tcs {
+		t.Run(name, func(t *testing.T) {
+			module := mustParseModuleInstanceStr(tc.module)
+			actual, expected := module.ContainingModule().String(), tc.expected
+			if actual != expected {
+				t.Errorf("expected: %s\nactual:  %s", expected, actual)
+			}
+		})
+	}
+}
+
 func mustParseModuleInstanceStr(str string) ModuleInstance {
 	mi, diags := ParseModuleInstanceStr(str)
 	if diags.HasErrors() {
