@@ -432,7 +432,7 @@ func TestParseProviderSourceStr(t *testing.T) {
 	for name, test := range tests {
 		got, diags := ParseProviderSourceString(name)
 		for _, problem := range deep.Equal(got, test.Want) {
-			t.Errorf(problem)
+			t.Error(problem)
 		}
 		if len(diags) > 0 {
 			if test.Err == false {
