@@ -26,6 +26,8 @@ import (
 	"github.com/hashicorp/terraform/internal/states/remote"
 	"github.com/hashicorp/terraform/internal/states/statemgr"
 
+	"maps"
+
 	coordinationv1 "k8s.io/api/coordination/v1"
 	coordinationclientv1 "k8s.io/client-go/kubernetes/typed/coordination/v1"
 )
@@ -351,12 +353,7 @@ func (c *RemoteClient) getLabels() map[string]string {
 		tfstateWorkspaceKey:    c.workspace,
 		managedByKey:           "terraform",
 	}
-
-	if len(c.labels) != 0 {
-		for k, v := range c.labels {
-			l[k] = v
-		}
-	}
+	maps.Copy(l, c.labels)
 
 	return l
 }
