@@ -258,19 +258,24 @@ in order to capture the filesystem context the remote workspace expects:
 		}
 	}
 
+	log.Printf("[TRACE] backend/remote: starting configuration upload at %q", configDir)
 	err = b.client.ConfigurationVersions.Upload(stopCtx, cv.UploadURL, configDir)
 	if err != nil {
 		return nil, generalError("Failed to upload configuration files", err)
 	}
+	log.Printf("[TRACE] backend/remote: finished configuration upload")
 
 	uploaded := false
 	for i := 0; i < 60 && !uploaded; i++ {
 		select {
 		case <-stopCtx.Done():
+			log.Printf("[TRACE] backend/remote: deadline reached while waiting for configuration status")
 			return nil, context.Canceled
 		case <-cancelCtx.Done():
+			log.Printf("[TRACE] backend/remote: operation cancelled while waiting for configuration status")
 			return nil, context.Canceled
 		case <-time.After(planConfigurationVersionsPollInterval):
+			log.Printf("[TRACE] backend/remote: reading configuration status")
 			cv, err = b.client.ConfigurationVersions.Read(stopCtx, cv.ID)
 			if err != nil {
 				return nil, generalError("Failed to retrieve configuration version", err)
@@ -287,6 +292,7 @@ in order to capture the filesystem context the remote workspace expects:
 			"Failed to upload configuration files", errors.New("operation timed out"))
 	}
 
+	log.Printf("[TRACE] backend/remote: configuration uploaded and ready")
 	runOptions := tfe.RunCreateOptions{
 		ConfigurationVersion: cv,
 		Refresh:              tfe.Bool(op.PlanRefresh),
@@ -411,6 +417,15 @@ in order to capture the filesystem context the remote workspace expects:
 		return r, generalError("Failed to retrieve run", err)
 	}
 
+	// Wait for post plan tasks to complete before proceeding.
+	// Otherwise, in the case of an apply, if they are still running
+	// when we check for whether the run is confirmable the CLI will
+	// uncermoniously exit before the user has a chance to confirm, or for an auto-apply to take place.
+	err = b.waitForPostPlanTasks(stopCtx, cancelCtx, r)
+	if err != nil {
+		return r, err
+	}
+
 	// If the run is canceled or errored, we still continue to the
 	// cost-estimation and policy check phases to ensure we render any
 	// results available. In the case of a hard-failed policy check, the
