@@ -148,7 +148,7 @@ func getSrc(v cty.Value) (string, bool, error) {
 		return expansion, false, err
 
 	default:
-		panic("source and content cannot both be null")
+		return "", false, errors.New("source and content cannot both be null")
 	}
 }
 
