@@ -4,13 +4,13 @@
 package cloud
 
 import (
-	"github.com/hashicorp/terraform/internal/backend"
+	"github.com/hashicorp/terraform/internal/backend/backendrun"
 	"github.com/hashicorp/terraform/internal/command/jsonformat"
 )
 
-// CLIInit implements backend.CLI
-func (b *Cloud) CLIInit(opts *backend.CLIOpts) error {
-	if cli, ok := b.local.(backend.CLI); ok {
+// CLIInit implements backendrun.CLI
+func (b *Cloud) CLIInit(opts *backendrun.CLIOpts) error {
+	if cli, ok := b.local.(backendrun.CLI); ok {
 		if err := cli.CLIInit(opts); err != nil {
 			return err
 		}
