@@ -24,7 +24,7 @@ func Test_backend_apply_before_init(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:           []string{"apply"},
-							expectedCmdOutput: `Terraform Cloud initialization required: please run "terraform init"`,
+							expectedCmdOutput: `HCP Terraform initialization required: please run "terraform init"`,
 							expectError:       true,
 						},
 					},
@@ -58,7 +58,7 @@ func Test_backend_apply_before_init(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:           []string{"apply"},
-							expectedCmdOutput: `Terraform Cloud initialization required: please run "terraform init"`,
+							expectedCmdOutput: `HCP Terraform initialization required: please run "terraform init"`,
 							expectError:       true,
 						},
 					},
