@@ -38,7 +38,7 @@ func Test_migrate_tfc_to_tfc_single_workspace(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:           []string{"init"},
-							expectedCmdOutput: `Terraform Cloud has been successfully initialized!`,
+							expectedCmdOutput: `HCP Terraform has been successfully initialized!`,
 						},
 						{
 							command:           []string{"workspace", "show"},
@@ -63,7 +63,7 @@ func Test_migrate_tfc_to_tfc_single_workspace(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:         []string{"init", "-ignore-remote-version"},
-							postInputOutput: []string{`Terraform Cloud has been successfully initialized!`},
+							postInputOutput: []string{`HCP Terraform has been successfully initialized!`},
 						},
 						{
 							command:           []string{"workspace", "show"},
@@ -98,7 +98,7 @@ func Test_migrate_tfc_to_tfc_single_workspace(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:           []string{"init"},
-							expectedCmdOutput: `Terraform Cloud has been successfully initialized!`,
+							expectedCmdOutput: `HCP Terraform has been successfully initialized!`,
 						},
 						{
 							command:         []string{"apply", "-auto-approve"},
@@ -119,7 +119,7 @@ func Test_migrate_tfc_to_tfc_single_workspace(t *testing.T) {
 							userInput:         []string{"new-workspace"},
 							postInputOutput: []string{
 								`Terraform can create a properly tagged workspace for you now.`,
-								`Terraform Cloud has been successfully initialized!`},
+								`HCP Terraform has been successfully initialized!`},
 						},
 						{
 							command:           []string{"workspace", "show"},
@@ -156,7 +156,7 @@ func Test_migrate_tfc_to_tfc_single_workspace(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:           []string{"init"},
-							expectedCmdOutput: `Terraform Cloud has been successfully initialized!`,
+							expectedCmdOutput: `HCP Terraform has been successfully initialized!`,
 						},
 						{
 							command:         []string{"apply", "-auto-approve"},
@@ -184,7 +184,7 @@ func Test_migrate_tfc_to_tfc_single_workspace(t *testing.T) {
 							userInput:         []string{"new-workspace"},
 							postInputOutput: []string{
 								`Terraform can create a properly tagged workspace for you now.`,
-								`Terraform Cloud has been successfully initialized!`},
+								`HCP Terraform has been successfully initialized!`},
 						},
 					},
 				},
@@ -237,7 +237,7 @@ func Test_migrate_tfc_to_tfc_multiple_workspace(t *testing.T) {
 							command:           []string{"init"},
 							expectedCmdOutput: `The currently selected workspace (default) does not exist.`,
 							userInput:         []string{"1"},
-							postInputOutput:   []string{`Terraform Cloud has been successfully initialized!`},
+							postInputOutput:   []string{`HCP Terraform has been successfully initialized!`},
 						},
 						{
 							command:           []string{"apply"},
@@ -275,7 +275,7 @@ func Test_migrate_tfc_to_tfc_multiple_workspace(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:           []string{"init", "-ignore-remote-version"},
-							expectedCmdOutput: `Terraform Cloud has been successfully initialized!`,
+							expectedCmdOutput: `HCP Terraform has been successfully initialized!`,
 							postInputOutput:   []string{`tag_val = "service"`},
 						},
 						{
@@ -318,7 +318,7 @@ func Test_migrate_tfc_to_tfc_multiple_workspace(t *testing.T) {
 							command:           []string{"init"},
 							expectedCmdOutput: `The currently selected workspace (default) does not exist.`,
 							userInput:         []string{"1"},
-							postInputOutput:   []string{`Terraform Cloud has been successfully initialized!`},
+							postInputOutput:   []string{`HCP Terraform has been successfully initialized!`},
 						},
 						{
 							command:           []string{"apply", "-auto-approve"},
@@ -345,7 +345,7 @@ func Test_migrate_tfc_to_tfc_multiple_workspace(t *testing.T) {
 							command:           []string{"init", "-ignore-remote-version"},
 							expectedCmdOutput: `There are no workspaces with the configured tags (billing)`,
 							userInput:         []string{"new-app-prod"},
-							postInputOutput:   []string{`Terraform Cloud has been successfully initialized!`},
+							postInputOutput:   []string{`HCP Terraform has been successfully initialized!`},
 						},
 					},
 				},
