@@ -354,7 +354,7 @@ func (runner *TestSuiteRunner) client(addr tfaddr.Module, id tfe.RegistryModuleI
 			return nil, nil, diags
 		}
 
-		token, err := cliConfigToken(addr.Package.Host, runner.Services)
+		token, err := CliConfigToken(addr.Package.Host, runner.Services)
 		if err != nil {
 			diags = diags.Append(tfdiags.AttributeValue(
 				tfdiags.Error,
