@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package e2etest
 
 import (
@@ -17,8 +20,7 @@ func TestProvisioner(t *testing.T) {
 	// allowed.
 	skipIfCannotAccessNetwork(t)
 
-	tf := e2e.NewBinary(terraformBin, "testdata/provisioner")
-	defer tf.Close()
+	tf := e2e.NewBinary(t, terraformBin, "testdata/provisioner")
 
 	//// INIT
 	_, stderr, err := tf.Run("init")
