@@ -31,16 +31,3 @@ func (v *FlagStringKV) Set(raw string) error {
 	(*v)[key] = value
 	return nil
 }
-
-// FlagStringSlice is a flag.Value implementation for parsing targets from the
-// command line, e.g. -target=aws_instance.foo -target=aws_vpc.bar
-type FlagStringSlice []string
-
-func (v *FlagStringSlice) String() string {
-	return ""
-}
-func (v *FlagStringSlice) Set(raw string) error {
-	*v = append(*v, raw)
-
-	return nil
-}
