@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package jsonprovider
 
 import (
@@ -5,24 +8,22 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 
-	"github.com/hashicorp/terraform/internal/configs/configschema"
+	"github.com/hashicorp/terraform/internal/providers"
 )
 
 func TestMarshalSchemas(t *testing.T) {
 	tests := []struct {
-		Input    map[string]*configschema.Block
-		Versions map[string]uint64
-		Want     map[string]*schema
+		Input map[string]providers.Schema
+		Want  map[string]*Schema
 	}{
 		{
 			nil,
-			map[string]uint64{},
-			map[string]*schema{},
+			map[string]*Schema{},
 		},
 	}
 
 	for _, test := range tests {
-		got := marshalSchemas(test.Input, test.Versions)
+		got := marshalSchemas(test.Input)
 		if !cmp.Equal(got, test.Want) {
 			t.Fatalf("wrong result:\n %v\n", cmp.Diff(got, test.Want))
 		}
@@ -31,12 +32,12 @@ func TestMarshalSchemas(t *testing.T) {
 
 func TestMarshalSchema(t *testing.T) {
 	tests := map[string]struct {
-		Input *configschema.Block
-		Want  *schema
+		Input providers.Schema
+		Want  *Schema
 	}{
 		"nil_block": {
-			nil,
-			&schema{},
+			providers.Schema{},
+			&Schema{},
 		},
 	}
 
