@@ -46,4 +46,14 @@ const (
 	MessageTestInterrupt MessageType = "test_interrupt"
 	MessageTestStatus    MessageType = "test_status"
 	MessageTestRetry     MessageType = "test_retry"
+
+	// List messages
+	MessageListStart         MessageType = "list_start"
+	MessageListResourceFound MessageType = "list_resource_found"
+
+	// Action messages
+	MessageActionStart    MessageType = "action_start"
+	MessageActionProgress MessageType = "action_progress"
+	MessageActionComplete MessageType = "action_complete"
+	MessageActionErrored  MessageType = "action_errored"
 )
