@@ -118,12 +118,12 @@ func TestOperation_planNoChanges(t *testing.T) {
 					Type: "test_resource",
 					Name: "somewhere",
 				}.Instance(addrs.NoKey).Absolute(addrs.RootModuleInstance)
-				schema, _ := schemas.ResourceTypeConfig(
+				schema := schemas.ResourceTypeConfig(
 					addrs.NewDefaultProvider("test"),
 					addr.Resource.Resource.Mode,
 					addr.Resource.Resource.Type,
 				)
-				ty := schema.ImpliedType()
+				ty := schema.Body.ImpliedType()
 				rc := &plans.ResourceInstanceChange{
 					Addr:        addr,
 					PrevRunAddr: addr,
@@ -139,7 +139,7 @@ func TestOperation_planNoChanges(t *testing.T) {
 						}),
 					},
 				}
-				rcs, err := rc.Encode(ty)
+				rcs, err := rc.Encode(schema)
 				if err != nil {
 					panic(err)
 				}
@@ -159,12 +159,12 @@ func TestOperation_planNoChanges(t *testing.T) {
 					Type: "test_resource",
 					Name: "somewhere",
 				}.Instance(addrs.NoKey).Absolute(addrs.RootModuleInstance)
-				schema, _ := schemas.ResourceTypeConfig(
+				schema := schemas.ResourceTypeConfig(
 					addrs.NewDefaultProvider("test"),
 					addr.Resource.Resource.Mode,
 					addr.Resource.Resource.Type,
 				)
-				ty := schema.ImpliedType()
+				ty := schema.Body.ImpliedType()
 				rc := &plans.ResourceInstanceChange{
 					Addr:        addr,
 					PrevRunAddr: addr,
@@ -180,7 +180,7 @@ func TestOperation_planNoChanges(t *testing.T) {
 						}),
 					},
 				}
-				rcs, err := rc.Encode(ty)
+				rcs, err := rc.Encode(schema)
 				if err != nil {
 					panic(err)
 				}
@@ -206,12 +206,12 @@ func TestOperation_planNoChanges(t *testing.T) {
 					Type: "test_resource",
 					Name: "somewhere",
 				}.Instance(addrs.NoKey).Absolute(addrs.RootModuleInstance)
-				schema, _ := schemas.ResourceTypeConfig(
+				schema := schemas.ResourceTypeConfig(
 					addrs.NewDefaultProvider("test"),
 					addr.Resource.Resource.Mode,
 					addr.Resource.Resource.Type,
 				)
-				ty := schema.ImpliedType()
+				ty := schema.Body.ImpliedType()
 				rc := &plans.ResourceInstanceChange{
 					Addr:        addr,
 					PrevRunAddr: addr,
@@ -227,7 +227,7 @@ func TestOperation_planNoChanges(t *testing.T) {
 						}),
 					},
 				}
-				rcs, err := rc.Encode(ty)
+				rcs, err := rc.Encode(schema)
 				if err != nil {
 					panic(err)
 				}
@@ -252,12 +252,11 @@ func TestOperation_planNoChanges(t *testing.T) {
 					Type: "test_resource",
 					Name: "anywhere",
 				}.Instance(addrs.NoKey).Absolute(addrs.RootModuleInstance)
-				schema, _ := schemas.ResourceTypeConfig(
+				schema := schemas.ResourceTypeConfig(
 					addrs.NewDefaultProvider("test"),
 					addr.Resource.Resource.Mode,
 					addr.Resource.Resource.Type,
 				)
-				ty := schema.ImpliedType()
 				rc := &plans.ResourceInstanceChange{
 					Addr:        addr,
 					PrevRunAddr: addrPrev,
@@ -276,7 +275,7 @@ func TestOperation_planNoChanges(t *testing.T) {
 						}),
 					},
 				}
-				rcs, err := rc.Encode(ty)
+				rcs, err := rc.Encode(schema)
 				if err != nil {
 					panic(err)
 				}
