@@ -5,44 +5,33 @@ package configschema
 
 import (
 	"fmt"
+	"slices"
 
-	"github.com/hashicorp/terraform/internal/lang/marks"
 	"github.com/zclconf/go-cty/cty"
 )
 
-// copyAndExtendPath returns a copy of a cty.Path with some additional
-// `cty.PathStep`s appended to its end, to simplify creating new child paths.
-func copyAndExtendPath(path cty.Path, nextSteps ...cty.PathStep) cty.Path {
-	newPath := make(cty.Path, len(path), len(path)+len(nextSteps))
-	copy(newPath, path)
-	newPath = append(newPath, nextSteps...)
-	return newPath
-}
+// WARNING: SensitivePaths must exactly mirror the WriteOnlyPaths method, since
+// they both use the same process just for different attribute types. Any fixes
+// here must be made in WriteOnlyPaths, and vice versa.
 
-// ValueMarks returns a set of path value marks for a given value and path,
-// based on the sensitive flag for each attribute within the schema. Nested
-// blocks are descended (if present in the given value).
-func (b *Block) ValueMarks(val cty.Value, path cty.Path) []cty.PathValueMarks {
-	var pvm []cty.PathValueMarks
+// SensitivePaths returns a set of paths into the given value that should
+// be marked as sensitive based on the static declarations in the schema.
+func (b *Block) SensitivePaths(val cty.Value, basePath cty.Path) []cty.Path {
+	var ret []cty.Path
+
+	// A block as a whole cannot be sensitive, so nothing to return
+	if val.IsNull() || !val.IsKnown() {
+		return ret
+	}
 
-	// We can mark attributes as sensitive even if the value is null
 	for name, attrS := range b.Attributes {
 		if attrS.Sensitive {
-			// Create a copy of the path, with this step added, to add to our PathValueMarks slice
-			attrPath := copyAndExtendPath(path, cty.GetAttrStep{Name: name})
-			pvm = append(pvm, cty.PathValueMarks{
-				Path:  attrPath,
-				Marks: cty.NewValueMarks(marks.Sensitive),
-			})
+			attrPath := slices.Concat(basePath, cty.GetAttrPath(name))
+			ret = append(ret, attrPath)
 		}
 	}
 
-	// If the value is null, no other marks are possible
-	if val.IsNull() {
-		return pvm
-	}
-
-	// Extract marks for nested attribute type values
+	// Extract paths for marks from nested attribute type values
 	for name, attrS := range b.Attributes {
 		// If the attribute has no nested type, or the nested type doesn't
 		// contain any sensitive attributes, skip inspecting it
@@ -51,12 +40,11 @@ func (b *Block) ValueMarks(val cty.Value, path cty.Path) []cty.PathValueMarks {
 		}
 
 		// Create a copy of the path, with this step added, to add to our PathValueMarks slice
-		attrPath := copyAndExtendPath(path, cty.GetAttrStep{Name: name})
-
-		pvm = append(pvm, attrS.NestedType.ValueMarks(val.GetAttr(name), attrPath)...)
+		attrPath := slices.Concat(basePath, cty.GetAttrPath(name))
+		ret = append(ret, attrS.NestedType.SensitivePaths(val.GetAttr(name), attrPath)...)
 	}
 
-	// Extract marks for nested blocks
+	// Extract paths for marks from nested blocks
 	for name, blockS := range b.BlockTypes {
 		// If our block doesn't contain any sensitive attributes, skip inspecting it
 		if !blockS.Block.ContainsSensitive() {
@@ -69,35 +57,35 @@ func (b *Block) ValueMarks(val cty.Value, path cty.Path) []cty.PathValueMarks {
 		}
 
 		// Create a copy of the path, with this step added, to add to our PathValueMarks slice
-		blockPath := copyAndExtendPath(path, cty.GetAttrStep{Name: name})
+		blockPath := slices.Concat(basePath, cty.GetAttrPath(name))
 
 		switch blockS.Nesting {
 		case NestingSingle, NestingGroup:
-			pvm = append(pvm, blockS.Block.ValueMarks(blockV, blockPath)...)
+			ret = append(ret, blockS.Block.SensitivePaths(blockV, blockPath)...)
 		case NestingList, NestingMap, NestingSet:
+			blockV, _ = blockV.Unmark() // peel off one level of marking so we can iterate
 			for it := blockV.ElementIterator(); it.Next(); {
 				idx, blockEV := it.Element()
 				// Create a copy of the path, with this block instance's index
 				// step added, to add to our PathValueMarks slice
-				blockInstancePath := copyAndExtendPath(blockPath, cty.IndexStep{Key: idx})
-				morePaths := blockS.Block.ValueMarks(blockEV, blockInstancePath)
-				pvm = append(pvm, morePaths...)
+				blockInstancePath := slices.Concat(blockPath, cty.IndexPath(idx))
+				morePaths := blockS.Block.SensitivePaths(blockEV, blockInstancePath)
+				ret = append(ret, morePaths...)
 			}
 		default:
 			panic(fmt.Sprintf("unsupported nesting mode %s", blockS.Nesting))
 		}
 	}
-	return pvm
+	return ret
 }
 
-// ValueMarks returns a set of path value marks for a given value and path,
-// based on the sensitive flag for each attribute within the nested attribute.
-// Attributes with nested types are descended (if present in the given value).
-func (o *Object) ValueMarks(val cty.Value, path cty.Path) []cty.PathValueMarks {
-	var pvm []cty.PathValueMarks
+// SensitivePaths returns a set of paths into the given value that should be
+// marked as sensitive based on the static declarations in the schema.
+func (o *Object) SensitivePaths(val cty.Value, basePath cty.Path) []cty.Path {
+	var ret []cty.Path
 
 	if val.IsNull() || !val.IsKnown() {
-		return pvm
+		return ret
 	}
 
 	for name, attrS := range o.Attributes {
@@ -109,22 +97,20 @@ func (o *Object) ValueMarks(val cty.Value, path cty.Path) []cty.PathValueMarks {
 		switch o.Nesting {
 		case NestingSingle, NestingGroup:
 			// Create a path to this attribute
-			attrPath := copyAndExtendPath(path, cty.GetAttrStep{Name: name})
+			attrPath := slices.Concat(basePath, cty.GetAttrPath(name))
 
 			if attrS.Sensitive {
 				// If the entire attribute is sensitive, mark it so
-				pvm = append(pvm, cty.PathValueMarks{
-					Path:  attrPath,
-					Marks: cty.NewValueMarks(marks.Sensitive),
-				})
+				ret = append(ret, attrPath)
 			} else {
 				// The attribute has a nested type which contains sensitive
 				// attributes, so recurse
-				pvm = append(pvm, attrS.NestedType.ValueMarks(val.GetAttr(name), attrPath)...)
+				ret = append(ret, attrS.NestedType.SensitivePaths(val.GetAttr(name), attrPath)...)
 			}
 		case NestingList, NestingMap, NestingSet:
 			// For nested attribute types which have a non-single nesting mode,
 			// we add path value marks for each element of the collection
+			val, _ = val.Unmark() // peel off one level of marking so we can iterate
 			for it := val.ElementIterator(); it.Next(); {
 				idx, attrEV := it.Element()
 				attrV := attrEV.GetAttr(name)
@@ -134,23 +120,18 @@ func (o *Object) ValueMarks(val cty.Value, path cty.Path) []cty.PathValueMarks {
 				// of the loops: index into the collection, then the contained
 				// attribute name. This is because we have one type
 				// representing multiple collection elements.
-				attrPath := copyAndExtendPath(path, cty.IndexStep{Key: idx}, cty.GetAttrStep{Name: name})
+				attrPath := slices.Concat(basePath, cty.IndexPath(idx).GetAttr(name))
 
 				if attrS.Sensitive {
 					// If the entire attribute is sensitive, mark it so
-					pvm = append(pvm, cty.PathValueMarks{
-						Path:  attrPath,
-						Marks: cty.NewValueMarks(marks.Sensitive),
-					})
+					ret = append(ret, attrPath)
 				} else {
-					// The attribute has a nested type which contains sensitive
-					// attributes, so recurse
-					pvm = append(pvm, attrS.NestedType.ValueMarks(attrV, attrPath)...)
+					ret = append(ret, attrS.NestedType.SensitivePaths(attrV, attrPath)...)
 				}
 			}
 		default:
 			panic(fmt.Sprintf("unsupported nesting mode %s", attrS.NestedType.Nesting))
 		}
 	}
-	return pvm
+	return ret
 }
