@@ -32,6 +32,24 @@ func TestAttributeByPath(t *testing.T) {
 					},
 				},
 			},
+			"a4": {
+				Description: "a3",
+				NestedType: &Object{
+					Nesting: NestingMap,
+					Attributes: map[string]*Attribute{
+						"nt1": {Description: "nt1"},
+						"nt2": {
+							Description: "nt2",
+							NestedType: &Object{
+								Nesting: NestingSingle,
+								Attributes: map[string]*Attribute{
+									"deeply_nested": {Description: "deeply_nested"},
+								},
+							},
+						},
+					},
+				},
+			},
 		},
 		BlockTypes: map[string]*NestedBlock{
 			"b1": {
@@ -97,6 +115,11 @@ func TestAttributeByPath(t *testing.T) {
 			"missing",
 			false,
 		},
+		{
+			cty.GetAttrPath("a3").IndexInt(1).GetAttr("nt2").GetAttr("deeply_nested"),
+			"deeply_nested",
+			true,
+		},
 		{
 			cty.GetAttrPath("b1"),
 			"block",
@@ -133,6 +156,11 @@ func TestAttributeByPath(t *testing.T) {
 			"a9",
 			true,
 		},
+		{
+			cty.GetAttrPath("a4").IndexString("test").GetAttr("nt2").GetAttr("deeply_nested"),
+			"deeply_nested",
+			true,
+		},
 	} {
 		t.Run(tc.attrDescription, func(t *testing.T) {
 			attr := schema.AttributeByPath(tc.path)
