@@ -33,6 +33,11 @@ func TestSourceAvailableVersions(t *testing.T) {
 			[]string{"0.1.0", "1.0.0", "1.2.0", "2.0.0"},
 			``,
 		},
+		{
+			"example.com/awesomesauce/invalidsemver",
+			[]string{"0.1.0", "1.0.0"},
+			``, // No error expected as invalid semvers are just logged and skipped
+		},
 		{
 			"example.com/weaksauce/no-versions",
 			nil,
