@@ -17,10 +17,12 @@ import (
 	version "github.com/hashicorp/go-version"
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
+
 	"github.com/hashicorp/terraform/internal/addrs"
 	"github.com/hashicorp/terraform/internal/configs"
 	"github.com/hashicorp/terraform/internal/configs/configload"
 	"github.com/hashicorp/terraform/internal/getmodules"
+	"github.com/hashicorp/terraform/internal/getmodules/moduleaddrs"
 	"github.com/hashicorp/terraform/internal/modsdir"
 	"github.com/hashicorp/terraform/internal/registry"
 	"github.com/hashicorp/terraform/internal/registry/regsrc"
@@ -135,7 +137,7 @@ func (i *ModuleInstaller) InstallModules(ctx context.Context, rootDir, testsDir
 	}
 	walker := i.moduleInstallWalker(ctx, manifest, upgrade, hooks, fetcher)
 
-	cfg, instDiags := i.installDescendentModules(rootMod, manifest, walker, installErrsOnly)
+	cfg, instDiags := i.installDescendantModules(rootMod, manifest, walker, installErrsOnly)
 	diags = append(diags, instDiags...)
 
 	return cfg, diags
@@ -200,7 +202,7 @@ func (i *ModuleInstaller) moduleInstallWalker(ctx context.Context, manifest mods
 					log.Printf("[TRACE] ModuleInstaller: discarding previous record of %s prior to reinstall", key)
 				}
 				delete(manifest, key)
-				// Deleting a module invalidates all of its descendent modules too.
+				// Deleting a module invalidates all of its descendant modules too.
 				keyPrefix := key + "."
 				for subKey := range manifest {
 					if strings.HasPrefix(subKey, keyPrefix) {
@@ -290,7 +292,7 @@ func (i *ModuleInstaller) moduleInstallWalker(ctx context.Context, manifest mods
 	)
 }
 
-func (i *ModuleInstaller) installDescendentModules(rootMod *configs.Module, manifest modsdir.Manifest, installWalker configs.ModuleWalker, installErrsOnly bool) (*configs.Config, tfdiags.Diagnostics) {
+func (i *ModuleInstaller) installDescendantModules(rootMod *configs.Module, manifest modsdir.Manifest, installWalker configs.ModuleWalker, installErrsOnly bool) (*configs.Config, tfdiags.Diagnostics) {
 	var diags tfdiags.Diagnostics
 
 	// When attempting to initialize the current directory with a module
@@ -310,7 +312,7 @@ func (i *ModuleInstaller) installDescendentModules(rootMod *configs.Module, mani
 		})
 	}
 
-	cfg, cDiags := configs.BuildConfig(rootMod, walker)
+	cfg, cDiags := configs.BuildConfig(rootMod, walker, configs.MockDataLoaderFunc(i.loader.LoadExternalMockData))
 	diags = diags.Append(cDiags)
 	if installErrsOnly {
 		// We can't continue if there was an error during installation, but
@@ -589,7 +591,7 @@ func (i *ModuleInstaller) installRegistryModule(ctx context.Context, req *config
 			})
 			return nil, nil, diags
 		}
-		realAddr, err := addrs.ParseModuleSource(realAddrRaw)
+		realAddr, err := moduleaddrs.ParseModuleSource(realAddrRaw)
 		if err != nil {
 			diags = diags.Append(&hcl.Diagnostic{
 				Severity: hcl.DiagError,
@@ -657,16 +659,45 @@ func (i *ModuleInstaller) installRegistryModule(ctx context.Context, req *config
 	// Finally we are ready to try actually loading the module.
 	mod, mDiags := i.loader.Parser().LoadConfigDir(modDir)
 	if mod == nil {
-		// nil indicates missing or unreadable directory, so we'll
-		// discard the returned diags and return a more specific
-		// error message here. For registry modules this actually
-		// indicates a bug in the code above, since it's not the
-		// user's responsibility to create the directory in this case.
-		diags = diags.Append(&hcl.Diagnostic{
-			Severity: hcl.DiagError,
-			Summary:  "Unreadable module directory",
-			Detail:   fmt.Sprintf("The directory %s could not be read. This is a bug in Terraform and should be reported.", modDir),
-		})
+		// a nil module indicates a missing or unreadable directory, typically
+		// this would indicate that Terraform has done something wrong.
+		// However, if the subDir is not empty then it is possible that the
+		// module was properly downloaded but the user is trying to read a
+		// subdirectory that doesn't exist. In this case, it's not a problem
+		// with Terraform.
+		if len(subDir) > 0 {
+			// Let's make this error message as precise as possible.
+			_, instErr := os.Stat(instPath)
+			_, subErr := os.Stat(modDir)
+			if instErr == nil && os.IsNotExist(subErr) {
+				// Then the root directory the module was downloaded to could
+				// be loaded fine, but the subdirectory does not exist. This
+				// definitely means the user is trying to read a subdirectory
+				// that doesn't exist.
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Unreadable module subdirectory",
+					Detail:   fmt.Sprintf("The directory %s does not exist. The target submodule %s does not exist within the target module.", modDir, subDir),
+				})
+			} else {
+				// There's something else gone wrong here, so we'll report it
+				// as a bug in Terraform.
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Unreadable module directory",
+					Detail:   fmt.Sprintf("The directory %s could not be read. This is a bug in Terraform and should be reported.", modDir),
+				})
+			}
+		} else {
+			// If there is no subDir, then somehow the module was downloaded but
+			// could not be read even at the root directory it was downloaded into.
+			// This is definitely something that Terraform is doing wrong.
+			diags = diags.Append(&hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Unreadable module directory",
+				Detail:   fmt.Sprintf("The directory %s could not be read. This is a bug in Terraform and should be reported.", modDir),
+			})
+		}
 	} else if vDiags := mod.CheckCoreVersionRequirements(req.Path, req.SourceAddr); vDiags.HasErrors() {
 		// If the core version requirements are not met, we drop any other
 		// diagnostics, as they may reflect language changes from future
@@ -711,7 +742,7 @@ func (i *ModuleInstaller) installGoGetterModule(ctx context.Context, req *config
 	if err != nil {
 		// go-getter generates a poor error for an invalid relative path, so
 		// we'll detect that case and generate a better one.
-		if _, ok := err.(*getmodules.MaybeRelativePathErr); ok {
+		if _, ok := err.(*moduleaddrs.MaybeRelativePathErr); ok {
 			log.Printf(
 				"[TRACE] ModuleInstaller: %s looks like a local path but is missing ./ or ../",
 				req.SourceAddr,
@@ -743,7 +774,7 @@ func (i *ModuleInstaller) installGoGetterModule(ctx context.Context, req *config
 		return nil, diags
 	}
 
-	modDir, err := getmodules.ExpandSubdirGlobs(instPath, addr.Subdir)
+	modDir, err := moduleaddrs.ExpandSubdirGlobs(instPath, addr.Subdir)
 	if err != nil {
 		diags = diags.Append(&hcl.Diagnostic{
 			Severity: hcl.DiagError,
