@@ -40,6 +40,7 @@ var LengthFunc = function.New(&function.Spec{
 		coll := args[0]
 		collTy := args[0].Type()
 		marks := coll.Marks()
+
 		switch {
 		case collTy == cty.DynamicPseudoType:
 			return cty.UnknownVal(cty.Number).WithMarks(marks), nil
@@ -222,14 +223,16 @@ var IndexFunc = function.New(&function.Spec{
 var LookupFunc = function.New(&function.Spec{
 	Params: []function.Parameter{
 		{
-			Name:        "inputMap",
-			Type:        cty.DynamicPseudoType,
-			AllowMarked: true,
+			Name:         "inputMap",
+			Type:         cty.DynamicPseudoType,
+			AllowMarked:  true,
+			AllowUnknown: true,
 		},
 		{
-			Name:        "key",
-			Type:        cty.String,
-			AllowMarked: true,
+			Name:         "key",
+			Type:         cty.String,
+			AllowMarked:  true,
+			AllowUnknown: true,
 		},
 	},
 	VarParam: &function.Parameter{
@@ -276,7 +279,7 @@ var LookupFunc = function.New(&function.Spec{
 		}
 	},
 	Impl: func(args []cty.Value, retType cty.Type) (ret cty.Value, err error) {
-		var defaultVal cty.Value
+		defaultVal := cty.NullVal(retType)
 		defaultValueSet := false
 
 		if len(args) == 3 {
@@ -297,12 +300,13 @@ var LookupFunc = function.New(&function.Spec{
 		if len(keyMarks) > 0 {
 			markses = append(markses, keyMarks)
 		}
-		lookupKey := keyVal.AsString()
 
-		if !mapVar.IsKnown() {
+		if !(mapVar.IsKnown() && keyVal.IsKnown()) {
 			return cty.UnknownVal(retType).WithMarks(markses...), nil
 		}
 
+		lookupKey := keyVal.AsString()
+
 		if mapVar.Type().IsObjectType() {
 			if mapVar.Type().HasAttribute(lookupKey) {
 				return mapVar.GetAttr(lookupKey).WithMarks(markses...), nil
@@ -511,7 +515,7 @@ var SumFunc = function.New(&function.Spec{
 		ty := args[0].Type()
 
 		if !ty.IsListType() && !ty.IsSetType() && !ty.IsTupleType() {
-			return cty.NilVal, function.NewArgErrorf(0, fmt.Sprintf("argument must be list, set, or tuple. Received %s", ty.FriendlyName()))
+			return cty.NilVal, function.NewArgErrorf(0, "argument must be list, set, or tuple. Received %s", ty.FriendlyName())
 		}
 
 		if !args[0].IsWhollyKnown() {
@@ -578,8 +582,14 @@ var TransposeFunc = function.New(&function.Spec{
 
 		for it := inputMap.ElementIterator(); it.Next(); {
 			inKey, inVal := it.Element()
+			if inVal.IsNull() {
+				return cty.MapValEmpty(cty.List(cty.String)), errors.New("input must not contain null list")
+			}
 			for iter := inVal.ElementIterator(); iter.Next(); {
 				_, val := iter.Element()
+				if val.IsNull() {
+					return cty.MapValEmpty(cty.List(cty.String)), errors.New("input list must not contain null string")
+				}
 				if !val.Type().Equals(cty.String) {
 					return cty.MapValEmpty(cty.List(cty.String)), errors.New("input must be a map of lists of strings")
 				}
