@@ -8,12 +8,12 @@ import (
 	"github.com/hashicorp/terraform/internal/configs"
 )
 
-type InitProviderOverrides func(map[string]addrs.Map[addrs.Targetable, *configs.Override])
+type InitProviderOverrides func(map[addrs.RootProviderConfig]addrs.Map[addrs.Targetable, *configs.Override])
 type InitLocalOverrides func(addrs.Map[addrs.Targetable, *configs.Override])
 
 func OverridesForTesting(providers InitProviderOverrides, locals InitLocalOverrides) *Overrides {
 	overrides := &Overrides{
-		providerOverrides: make(map[string]addrs.Map[addrs.Targetable, *configs.Override]),
+		providerOverrides: make(map[addrs.RootProviderConfig]addrs.Map[addrs.Targetable, *configs.Override]),
 		localOverrides:    addrs.MakeMap[addrs.Targetable, *configs.Override](),
 	}
 
