@@ -1,8 +1,12 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package providercache
 
 import (
 	"context"
 	"fmt"
+	"log"
 	"sort"
 	"strings"
 
@@ -36,6 +40,12 @@ type Installer struct {
 	// version between different configurations on the same system.
 	globalCacheDir *Dir
 
+	// globalCacheDirMayBreakDependencyLockFile allows a temporary exception to
+	// the rule that an entry in globalCacheDir can normally only be used if
+	// its validity is already confirmed by an entry in the dependency lock
+	// file.
+	globalCacheDirMayBreakDependencyLockFile bool
+
 	// builtInProviderTypes is an optional set of types that should be
 	// considered valid to appear in the special terraform.io/builtin/...
 	// namespace, which we use for providers that are built in to Terraform
@@ -103,6 +113,19 @@ func (i *Installer) SetGlobalCacheDir(cacheDir *Dir) {
 	i.globalCacheDir = cacheDir
 }
 
+// SetGlobalCacheDirMayBreakDependencyLockFile activates or deactivates our
+// temporary exception to the rule that the global cache directory can be used
+// only when entries are confirmed by existing entries in the dependency lock
+// file.
+//
+// If this is set then if we install a provider for the first time from the
+// cache then the dependency lock file will include only the checksum from
+// the package in the global cache, which means the lock file won't be portable
+// to Terraform running on another operating system or CPU architecture.
+func (i *Installer) SetGlobalCacheDirMayBreakDependencyLockFile(mayBreak bool) {
+	i.globalCacheDirMayBreakDependencyLockFile = mayBreak
+}
+
 // HasGlobalCacheDir returns true if someone has previously called
 // SetGlobalCacheDir to configure a global cache directory for this installer.
 func (i *Installer) HasGlobalCacheDir() bool {
@@ -347,89 +370,169 @@ NeedProvider:
 			// Step 3a: If our global cache already has this version available then
 			// we'll just link it in.
 			if cached := i.globalCacheDir.ProviderVersion(provider, version); cached != nil {
-				if cb := evts.LinkFromCacheBegin; cb != nil {
-					cb(provider, version, i.globalCacheDir.baseDir)
-				}
-				if _, err := cached.ExecutableFile(); err != nil {
-					err := fmt.Errorf("provider binary not found: %s", err)
-					errs[provider] = err
-					if cb := evts.LinkFromCacheFailure; cb != nil {
-						cb(provider, version, err)
+				// An existing cache entry is only an acceptable choice
+				// if there is already a lock file entry for this provider
+				// and the cache entry matches its checksums.
+				//
+				// If there was no lock file entry at all then we need to
+				// install the package for real so that we can lock as complete
+				// as possible a set of checksums for all of this provider's
+				// packages.
+				//
+				// If there was a lock file entry but the cache doesn't match
+				// it then we assume that the lock file checksums were only
+				// partially populated (e.g. from a local mirror where we can
+				// only see one package to checksum it) and so we'll fetch
+				// from upstream to see if the origin can give us a package
+				// that _does_ match. This might still not work out, but if
+				// it does then it allows us to avoid returning a checksum
+				// mismatch error.
+				acceptablePackage := false
+				if len(preferredHashes) != 0 {
+					var err error
+					acceptablePackage, err = cached.MatchesAnyHash(preferredHashes)
+					if err != nil {
+						// If we can't calculate the checksum for the cached
+						// package then we'll just treat it as a checksum failure.
+						acceptablePackage = false
 					}
-					continue
 				}
 
-				err := i.targetDir.LinkFromOtherCache(cached, preferredHashes)
-				if err != nil {
-					errs[provider] = err
-					if cb := evts.LinkFromCacheFailure; cb != nil {
-						cb(provider, version, err)
-					}
-					continue
-				}
-				// We'll fetch what we just linked to make sure it actually
-				// did show up there.
-				new := i.targetDir.ProviderVersion(provider, version)
-				if new == nil {
-					err := fmt.Errorf("after linking %s from provider cache at %s it is still not detected in the target directory; this is a bug in Terraform", provider, i.globalCacheDir.baseDir)
-					errs[provider] = err
-					if cb := evts.LinkFromCacheFailure; cb != nil {
-						cb(provider, version, err)
-					}
-					continue
-				}
-
-				// The LinkFromOtherCache call above should've verified that
-				// the package matches one of the hashes previously recorded,
-				// if any. We'll now augment those hashes with one freshly
-				// calculated from the package we just linked, which allows
-				// the lock file to gradually transition to recording newer hash
-				// schemes when they become available.
-				var newHashes []getproviders.Hash
-				if lock != nil && lock.Version() == version {
-					// If the version we're installing is identical to the
-					// one we previously locked then we'll keep all of the
-					// hashes we saved previously and add to it. Otherwise
-					// we'll be starting fresh, because each version has its
-					// own set of packages and thus its own hashes.
-					newHashes = append(newHashes, preferredHashes...)
-
-					// NOTE: The behavior here is unfortunate when a particular
-					// provider version was already cached on the first time
-					// the current configuration requested it, because that
-					// means we don't currently get the opportunity to fetch
-					// and verify the checksums for the new package from
-					// upstream. That's currently unavoidable because upstream
-					// checksums are in the "ziphash" format and so we can't
-					// verify them against our cache directory's unpacked
-					// packages: we'd need to go fetch the package from the
-					// origin and compare against it, which would defeat the
-					// purpose of the global cache.
+				if !acceptablePackage && i.globalCacheDirMayBreakDependencyLockFile {
+					// The "may break dependency lock file" setting effectively
+					// means that we'll accept any matching package that's
+					// already in the cache, regardless of whether it matches
+					// what's in the dependency lock file.
 					//
-					// If we fetch from upstream on the first encounter with
-					// a particular provider then we'll end up in the other
-					// codepath below where we're able to also include the
-					// checksums from the origin registry.
+					// That means two less-ideal situations might occur:
+					// - If this provider is not currently tracked in the lock
+					//   file at all then after installation the lock file will
+					//   only accept the package that was already present in
+					//   the cache as a valid checksum. That means the generated
+					//   lock file won't be portable to other operating systems
+					//   or CPU architectures.
+					// - If the provider _is_ currently tracked in the lock file
+					//   but the checksums there don't match what was in the
+					//   cache then the LinkFromOtherCache call below will
+					//   fail with a checksum error, and the user will need to
+					//   either manually remove the entry from the lock file
+					//   or remove the mismatching item from the cache,
+					//   depending on which of these they prefer to use as the
+					//   source of truth for the expected contents of the
+					//   package.
+					//
+					// If the lock file already includes this provider and the
+					// cache entry matches one of the locked checksums then
+					// there's no problem, but in that case we wouldn't enter
+					// this branch because acceptablePackage would already be
+					// true from the check above.
+					log.Printf(
+						"[WARN] plugin_cache_may_break_dependency_lock_file: Using global cache dir package for %s v%s even though it doesn't match this configuration's dependency lock file",
+						provider.String(), version.String(),
+					)
+					acceptablePackage = true
 				}
-				newHash, err := cached.Hash()
-				if err != nil {
-					err := fmt.Errorf("after linking %s from provider cache at %s, failed to compute a checksum for it: %s", provider, i.globalCacheDir.baseDir, err)
-					errs[provider] = err
-					if cb := evts.LinkFromCacheFailure; cb != nil {
-						cb(provider, version, err)
-					}
-					continue
-				}
-				// The hashes slice gets deduplicated in the lock file
-				// implementation, so we don't worry about potentially
-				// creating a duplicate here.
-				newHashes = append(newHashes, newHash)
-				locks.SetProvider(provider, version, reqs[provider], newHashes)
 
-				if cb := evts.LinkFromCacheSuccess; cb != nil {
-					cb(provider, version, new.PackageDir)
+				// TODO: Should we emit an event through the events object
+				// for "there was an entry in the cache but we ignored it
+				// because the checksum didn't match"? We can't use
+				// LinkFromCacheFailure in that case because this isn't a
+				// failure. For now we'll just be quiet about it.
+
+				if acceptablePackage {
+					if cb := evts.LinkFromCacheBegin; cb != nil {
+						cb(provider, version, i.globalCacheDir.baseDir)
+					}
+					if _, err := cached.ExecutableFile(); err != nil {
+						err := fmt.Errorf("provider binary not found: %s", err)
+						errs[provider] = err
+						if cb := evts.LinkFromCacheFailure; cb != nil {
+							cb(provider, version, err)
+						}
+						continue
+					}
+
+					err := i.targetDir.LinkFromOtherCache(cached, preferredHashes)
+					if err != nil {
+						errs[provider] = err
+						if cb := evts.LinkFromCacheFailure; cb != nil {
+							cb(provider, version, err)
+						}
+						continue
+					}
+					// We'll fetch what we just linked to make sure it actually
+					// did show up there.
+					new := i.targetDir.ProviderVersion(provider, version)
+					if new == nil {
+						err := fmt.Errorf("after linking %s from provider cache at %s it is still not detected in the target directory; this is a bug in Terraform", provider, i.globalCacheDir.baseDir)
+						errs[provider] = err
+						if cb := evts.LinkFromCacheFailure; cb != nil {
+							cb(provider, version, err)
+						}
+						continue
+					}
+
+					// The LinkFromOtherCache call above should've verified that
+					// the package matches one of the hashes previously recorded,
+					// if any. We'll now augment those hashes with one freshly
+					// calculated from the package we just linked, which allows
+					// the lock file to gradually transition to recording newer hash
+					// schemes when they become available.
+					var priorHashes []getproviders.Hash
+					if lock != nil && lock.Version() == version {
+						// If the version we're installing is identical to the
+						// one we previously locked then we'll keep all of the
+						// hashes we saved previously and add to it. Otherwise
+						// we'll be starting fresh, because each version has its
+						// own set of packages and thus its own hashes.
+						priorHashes = append(priorHashes, preferredHashes...)
+
+						// NOTE: The behavior here is unfortunate when a particular
+						// provider version was already cached on the first time
+						// the current configuration requested it, because that
+						// means we don't currently get the opportunity to fetch
+						// and verify the checksums for the new package from
+						// upstream. That's currently unavoidable because upstream
+						// checksums are in the "ziphash" format and so we can't
+						// verify them against our cache directory's unpacked
+						// packages: we'd need to go fetch the package from the
+						// origin and compare against it, which would defeat the
+						// purpose of the global cache.
+						//
+						// If we fetch from upstream on the first encounter with
+						// a particular provider then we'll end up in the other
+						// codepath below where we're able to also include the
+						// checksums from the origin registry.
+					}
+					newHash, err := cached.Hash()
+					if err != nil {
+						err := fmt.Errorf("after linking %s from provider cache at %s, failed to compute a checksum for it: %s", provider, i.globalCacheDir.baseDir, err)
+						errs[provider] = err
+						if cb := evts.LinkFromCacheFailure; cb != nil {
+							cb(provider, version, err)
+						}
+						continue
+					}
+					// The hashes slice gets deduplicated in the lock file
+					// implementation, so we don't worry about potentially
+					// creating a duplicate here.
+					var newHashes []getproviders.Hash
+					newHashes = append(newHashes, priorHashes...)
+					newHashes = append(newHashes, newHash)
+					locks.SetProvider(provider, version, reqs[provider], newHashes)
+					if cb := evts.ProvidersLockUpdated; cb != nil {
+						// We want to ensure that newHash and priorHashes are
+						// sorted. newHash is a single value, so it's definitely
+						// sorted. priorHashes are pulled from the lock file, so
+						// are also already sorted.
+						cb(provider, version, []getproviders.Hash{newHash}, nil, priorHashes)
+					}
+
+					if cb := evts.LinkFromCacheSuccess; cb != nil {
+						cb(provider, version, new.PackageDir)
+					}
+					continue // Don't need to do full install, then.
 				}
-				continue // Don't need to do full install, then.
 			}
 		}
 
@@ -464,7 +567,13 @@ NeedProvider:
 			installTo = i.targetDir
 			linkTo = nil // no linking needed
 		}
-		authResult, err := installTo.InstallPackage(ctx, meta, preferredHashes)
+
+		allowedHashes := preferredHashes
+		if mode.forceInstallChecksums() {
+			allowedHashes = []getproviders.Hash{}
+		}
+
+		authResult, err := installTo.InstallPackage(ctx, meta, allowedHashes)
 		if err != nil {
 			// TODO: Consider retrying for certain kinds of error that seem
 			// likely to be transient. For now, we just treat all errors equally.
@@ -476,7 +585,7 @@ NeedProvider:
 		}
 		new := installTo.ProviderVersion(provider, version)
 		if new == nil {
-			err := fmt.Errorf("after installing %s it is still not detected in the target directory; this is a bug in Terraform", provider)
+			err := fmt.Errorf("after installing %s it is still not detected in %s; this is a bug in Terraform", provider, installTo.BasePath())
 			errs[provider] = err
 			if cb := evts.FetchPackageFailure; cb != nil {
 				cb(provider, version, err)
@@ -506,6 +615,28 @@ NeedProvider:
 				}
 				continue
 			}
+
+			// We should now also find the package in the linkTo dir, which
+			// gives us the final value of "new" where the path points in to
+			// the true target directory, rather than possibly the global
+			// cache directory.
+			new = linkTo.ProviderVersion(provider, version)
+			if new == nil {
+				err := fmt.Errorf("after installing %s it is still not detected in %s; this is a bug in Terraform", provider, linkTo.BasePath())
+				errs[provider] = err
+				if cb := evts.FetchPackageFailure; cb != nil {
+					cb(provider, version, err)
+				}
+				continue
+			}
+			if _, err := new.ExecutableFile(); err != nil {
+				err := fmt.Errorf("provider binary not found: %s", err)
+				errs[provider] = err
+				if cb := evts.FetchPackageFailure; cb != nil {
+					cb(provider, version, err)
+				}
+				continue
+			}
 		}
 		authResults[provider] = authResult
 
@@ -524,14 +655,14 @@ NeedProvider:
 		// The hashes slice gets deduplicated in the lock file
 		// implementation, so we don't worry about potentially
 		// creating duplicates here.
-		var newHashes []getproviders.Hash
+		var priorHashes []getproviders.Hash
 		if lock != nil && lock.Version() == version {
 			// If the version we're installing is identical to the
 			// one we previously locked then we'll keep all of the
 			// hashes we saved previously and add to it. Otherwise
 			// we'll be starting fresh, because each version has its
 			// own set of packages and thus its own hashes.
-			newHashes = append(newHashes, preferredHashes...)
+			priorHashes = append(priorHashes, preferredHashes...)
 		}
 		newHash, err := new.Hash()
 		if err != nil {
@@ -542,15 +673,32 @@ NeedProvider:
 			}
 			continue
 		}
-		newHashes = append(newHashes, newHash)
+
+		var signedHashes []getproviders.Hash
 		if authResult.SignedByAnyParty() {
 			// We'll trust new hashes from upstream only if they were verified
 			// as signed by a suitable key. Otherwise, we'd record only
 			// a new hash we just calculated ourselves from the bytes on disk,
 			// and so the hashes would cover only the current platform.
-			newHashes = append(newHashes, meta.AcceptableHashes()...)
+			signedHashes = append(signedHashes, meta.AcceptableHashes()...)
 		}
+
+		var newHashes []getproviders.Hash
+		newHashes = append(newHashes, newHash)
+		newHashes = append(newHashes, priorHashes...)
+		newHashes = append(newHashes, signedHashes...)
+
 		locks.SetProvider(provider, version, reqs[provider], newHashes)
+		if cb := evts.ProvidersLockUpdated; cb != nil {
+			// newHash and priorHashes are already sorted.
+			// But we do need to sort signedHashes so we can reason about it
+			// sensibly.
+			sort.Slice(signedHashes, func(i, j int) bool {
+				return string(signedHashes[i]) < string(signedHashes[j])
+			})
+
+			cb(provider, version, []getproviders.Hash{newHash}, signedHashes, priorHashes)
+		}
 
 		if cb := evts.FetchPackageSuccess; cb != nil {
 			cb(provider, version, new.PackageDir, authResult)
@@ -594,6 +742,11 @@ const (
 	// sets.
 	InstallNewProvidersOnly InstallMode = 'N'
 
+	// InstallNewProvidersForce is an InstallMode that follows the same
+	// logic as InstallNewProvidersOnly except it does not verify existing
+	// checksums but force installs new checksums for all given providers.
+	InstallNewProvidersForce InstallMode = 'F'
+
 	// InstallUpgrades is an InstallMode that causes the installer to check
 	// all requested providers to see if new versions are available that
 	// are also in the given version sets, even if a suitable version of
@@ -605,6 +758,10 @@ func (m InstallMode) forceQueryAllProviders() bool {
 	return m == InstallUpgrades
 }
 
+func (m InstallMode) forceInstallChecksums() bool {
+	return m == InstallNewProvidersForce
+}
+
 // InstallerError is an error type that may be returned (but is not guaranteed)
 // from Installer.EnsureProviderVersions to indicate potentially several
 // separate failed installation outcomes for different providers included in
