@@ -39,6 +39,10 @@ type Interface interface {
 	// ephemeral resource configuration values.
 	ValidateEphemeralResourceConfig(ValidateEphemeralResourceConfigRequest) ValidateEphemeralResourceConfigResponse
 
+	// ValidateListResourceConfig allows the provider to validate the list
+	// resource configuration values.
+	ValidateListResourceConfig(ValidateListResourceConfigRequest) ValidateListResourceConfigResponse
+
 	// UpgradeResourceState is called when the state loader encounters an
 	// instance state whose schema version is less than the one reported by the
 	// currently-used version of the corresponding provider, and the upgraded
@@ -100,6 +104,23 @@ type Interface interface {
 	// CallFunction calls a provider-contributed function.
 	CallFunction(CallFunctionRequest) CallFunctionResponse
 
+	// ListResource queries the remote for a specific resource type and returns an iterator of items
+	//
+	// An error indicates that there was a problem before calling the provider,
+	// like a missing schema. Problems during a list operation are reported as
+	// diagnostics on the yielded events.
+	ListResource(ListResourceRequest) ListResourceResponse
+
+	// ValidateStateStoreConfig performs configuration validation
+	ValidateStateStoreConfig(ValidateStateStoreConfigRequest) ValidateStateStoreConfigResponse
+	// ConfigureStateStore configures the state store, such as S3 connection in the context of already configured provider
+	ConfigureStateStore(ConfigureStateStoreRequest) ConfigureStateStoreResponse
+
+	// GetStates returns a list of all states (i.e. CE workspaces) managed by a given state store
+	GetStates(GetStatesRequest) GetStatesResponse
+	// DeleteState instructs a given state store to delete a specific state (i.e. a CE workspace)
+	DeleteState(DeleteStateRequest) DeleteStateResponse
+
 	// Close shuts down the plugin process if applicable.
 	Close() error
 }
@@ -126,10 +147,17 @@ type GetProviderSchemaResponse struct {
 	// to its schema.
 	EphemeralResourceTypes map[string]Schema
 
+	// ListResourceTypes maps the name of a list resource type to its
+	// schema.
+	ListResourceTypes map[string]Schema
+
 	// Functions maps from local function name (not including an namespace
 	// prefix) to the declaration of a function.
 	Functions map[string]FunctionDecl
 
+	// StateStores maps the state store type name to that type's schema.
+	StateStores map[string]Schema
+
 	// Diagnostics contains any warnings or errors from the method call.
 	Diagnostics tfdiags.Diagnostics
 
@@ -261,6 +289,29 @@ type ValidateEphemeralResourceConfigResponse struct {
 	Diagnostics tfdiags.Diagnostics
 }
 
+type ValidateListResourceConfigRequest struct {
+	// TypeName is the name of the list resource type to validate.
+	TypeName string
+
+	// Config is the configuration value to validate, which may contain unknown
+	// values.
+	Config cty.Value
+
+	// IncludeResourceObject is the value of the include_resource
+	// argument in the list block. This is a cty value so that it can
+	// contain unknown values.
+	IncludeResourceObject cty.Value
+
+	// Limit is the maximum number of results to return. This is a
+	// cty value so that it can contain unknown values.
+	Limit cty.Value
+}
+
+type ValidateListResourceConfigResponse struct {
+	// Diagnostics contains any warnings or errors from the method call.
+	Diagnostics tfdiags.Diagnostics
+}
+
 type UpgradeResourceStateRequest struct {
 	// TypeName is the name of the resource type being upgraded
 	TypeName string
@@ -687,3 +738,77 @@ type CallFunctionResponse struct {
 	// specific argument.
 	Err error
 }
+
+type ListResourceResponse struct {
+	Result cty.Value
+
+	Diagnostics tfdiags.Diagnostics
+}
+
+type ListResourceRequest struct {
+	// TypeName is the name of the resource type being read.
+	TypeName string
+
+	// Config is the block body for the list resource.
+	Config cty.Value
+
+	// IncludeResourceObject can be set to true when a provider should include
+	// the full resource object for each result
+	IncludeResourceObject bool
+
+	// Limit is the maximum number of results to return
+	Limit int64
+}
+
+type ValidateStateStoreConfigRequest struct {
+	// TypeName is the name of the state store to validate.
+	TypeName string
+
+	// Config is the configuration value to validate.
+	Config cty.Value
+}
+
+type ValidateStateStoreConfigResponse struct {
+	// Diagnostics contains any warnings or errors from the method call.
+	Diagnostics tfdiags.Diagnostics
+}
+
+type ConfigureStateStoreRequest struct {
+	// TypeName is the name of the state store to configure
+	TypeName string
+
+	// Config is the configuration value to configure the store with.
+	Config cty.Value
+}
+
+type ConfigureStateStoreResponse struct {
+	// Diagnostics contains any warnings or errors from the method call.
+	Diagnostics tfdiags.Diagnostics
+}
+
+type GetStatesRequest struct {
+	// TypeName is the name of the state store to request the list of states from
+	TypeName string
+}
+
+type GetStatesResponse struct {
+	// States is a list of state names, sourced by inspecting persisted state data
+	States []string
+
+	// Diagnostics contains any warnings or errors from the method call.
+	Diagnostics tfdiags.Diagnostics
+}
+
+type DeleteStateRequest struct {
+	// TypeName is the name of the state store to request deletion from
+	TypeName string
+
+	// StateId is the name of the state to be deleted. This is the same as
+	// the concept of CE workspaces.
+	StateId string
+}
+
+type DeleteStateResponse struct {
+	// Diagnostics contains any warnings or errors from the method call.
+	Diagnostics tfdiags.Diagnostics
+}
