@@ -434,24 +434,6 @@ Each resource can have moved from only one source resource.`,
 			},
 			WantError: ``, // This is okay because the call itself is not considered to be inside the package it refers to
 		},
-		"resource type mismatch": {
-			Statements: []MoveStatement{
-				makeTestMoveStmt(t, ``,
-					`test.nonexist1`,
-					`other.single`,
-				),
-			},
-			WantError: `Resource type mismatch: This statement declares a move from test.nonexist1 to other.single, which is a resource of a different type.`,
-		},
-		"resource instance type mismatch": {
-			Statements: []MoveStatement{
-				makeTestMoveStmt(t, ``,
-					`test.nonexist1[0]`,
-					`other.single`,
-				),
-			},
-			WantError: `Resource type mismatch: This statement declares a move from test.nonexist1[0] to other.single, which is a resource instance of a different type.`,
-		},
 		"crossing nested statements": {
 			// overlapping nested moves will result in a cycle.
 			Statements: []MoveStatement{
@@ -554,7 +536,7 @@ func loadRefactoringFixture(t *testing.T, dir string) (*configs.Config, instance
 		t.Fatalf("failed to load root module: %s", diags.Error())
 	}
 
-	expander := instances.NewExpander()
+	expander := instances.NewExpander(nil)
 	staticPopulateExpanderModule(t, rootCfg, addrs.RootModuleInstance, expander)
 	return rootCfg, expander.AllInstances()
 }
@@ -562,7 +544,7 @@ func loadRefactoringFixture(t *testing.T, dir string) (*configs.Config, instance
 func staticPopulateExpanderModule(t *testing.T, rootCfg *configs.Config, moduleAddr addrs.ModuleInstance, expander *instances.Expander) {
 	t.Helper()
 
-	modCfg := rootCfg.DescendentForInstance(moduleAddr)
+	modCfg := rootCfg.DescendantForInstance(moduleAddr)
 	if modCfg == nil {
 		t.Fatalf("no configuration for %s", moduleAddr)
 	}
@@ -615,7 +597,7 @@ func staticPopulateExpanderModule(t *testing.T, rootCfg *configs.Config, moduleA
 
 		// We need to recursively analyze the child modules too.
 		calledMod := modCfg.Path.Child(call.Name)
-		for _, inst := range expander.ExpandModule(calledMod) {
+		for _, inst := range expander.ExpandModule(calledMod, false) {
 			staticPopulateExpanderModule(t, rootCfg, inst, expander)
 		}
 	}
