@@ -62,12 +62,14 @@ type TestCycle struct {
 	planMode           plans.Mode
 	planInputs         map[string]cty.Value
 	wantPlannedChanges []stackplan.PlannedChange
+	wantPlannedHooks   *ExpectedHooks
 	wantPlannedDiags   tfdiags.Diagnostics
 
 	// Apply options
 
 	applyInputs        map[string]cty.Value
 	wantAppliedChanges []stackstate.AppliedChange
+	wantAppliedHooks   *ExpectedHooks
 	wantAppliedDiags   tfdiags.Diagnostics
 }
 
@@ -84,8 +86,6 @@ func (tc TestContext) Validate(t *testing.T, ctx context.Context, cycle TestCycl
 }
 
 func (tc TestContext) Plan(t *testing.T, ctx context.Context, state *stackstate.State, cycle TestCycle) *stackplan.Plan {
-	t.Helper()
-
 	request := PlanRequest{
 		PlanMode:  cycle.planMode,
 		Config:    tc.config,
@@ -110,7 +110,8 @@ func (tc TestContext) Plan(t *testing.T, ctx context.Context, state *stackstate.
 		Diagnostics:    diagsCh,
 	}
 
-	go Plan(ctx, &request, &response)
+	capturedHooks := NewCapturedHooks(true)
+	go Plan(ContextWithHooks(ctx, capturedHooks.captureHooks()), &request, &response)
 	changes, diags := collectPlanOutput(changesCh, diagsCh)
 	validateDiags(t, cycle.wantPlannedDiags, diags)
 
@@ -140,6 +141,10 @@ func (tc TestContext) Plan(t *testing.T, ctx context.Context, state *stackstate.
 		}
 	}
 
+	if cycle.wantPlannedHooks != nil {
+		cycle.wantPlannedHooks.Validate(t, &capturedHooks.ExpectedHooks)
+	}
+
 	planLoader := stackplan.NewLoader()
 	for _, change := range changes {
 		proto, err := change.PlannedChangeProto()
@@ -163,8 +168,6 @@ func (tc TestContext) Plan(t *testing.T, ctx context.Context, state *stackstate.
 }
 
 func (tc TestContext) Apply(t *testing.T, ctx context.Context, plan *stackplan.Plan, cycle TestCycle) *stackstate.State {
-	t.Helper()
-
 	request := ApplyRequest{
 		Config: tc.config,
 		Plan:   plan,
@@ -187,7 +190,8 @@ func (tc TestContext) Apply(t *testing.T, ctx context.Context, plan *stackplan.P
 		Diagnostics:    diagsCh,
 	}
 
-	go Apply(ctx, &request, &response)
+	capturedHooks := NewCapturedHooks(false)
+	go Apply(ContextWithHooks(ctx, capturedHooks.captureHooks()), &request, &response)
 	changes, diags := collectApplyOutput(changesCh, diagsCh)
 	validateDiags(t, cycle.wantAppliedDiags, diags)
 
@@ -201,6 +205,10 @@ func (tc TestContext) Apply(t *testing.T, ctx context.Context, plan *stackplan.P
 		}
 	}
 
+	if cycle.wantAppliedHooks != nil {
+		cycle.wantAppliedHooks.Validate(t, &capturedHooks.ExpectedHooks)
+	}
+
 	stateLoader := stackstate.NewLoader()
 	for _, change := range changes {
 		proto, err := change.AppliedChangeProto()
