@@ -16,6 +16,7 @@ import (
 	"github.com/hashicorp/terraform/internal/instances"
 	"github.com/hashicorp/terraform/internal/lang"
 	"github.com/hashicorp/terraform/internal/lang/marks"
+	"github.com/hashicorp/terraform/internal/plans"
 	"github.com/hashicorp/terraform/internal/promising"
 	"github.com/hashicorp/terraform/internal/stacks/stackaddrs"
 	"github.com/hashicorp/terraform/internal/stacks/stackplan"
@@ -31,8 +32,10 @@ import (
 // are holding a valid [StackCallInstance] then you can call
 // [StackCallInstance.CalledStack] to get that stack.
 type StackCallInstance struct {
-	call *StackCall
-	key  addrs.InstanceKey
+	call     *StackCall
+	key      addrs.InstanceKey
+	deferred bool
+	mode     plans.Mode
 
 	main *Main
 
@@ -45,10 +48,12 @@ type StackCallInstance struct {
 var _ ExpressionScope = (*StackCallInstance)(nil)
 var _ Plannable = (*StackCallInstance)(nil)
 
-func newStackCallInstance(call *StackCall, key addrs.InstanceKey, repetition instances.RepetitionData) *StackCallInstance {
+func newStackCallInstance(call *StackCall, key addrs.InstanceKey, repetition instances.RepetitionData, mode plans.Mode, deferred bool) *StackCallInstance {
 	return &StackCallInstance{
 		call:       call,
 		key:        key,
+		deferred:   deferred,
+		mode:       mode,
 		main:       call.main,
 		repetition: repetition,
 	}
@@ -67,7 +72,7 @@ func (c *StackCallInstance) CalledStackAddr() stackaddrs.StackInstance {
 
 func (c *StackCallInstance) Stack(ctx context.Context, phase EvalPhase) *Stack {
 	stack, err := c.stack.For(phase).Do(ctx, c.tracingName(), func(ctx context.Context) (*Stack, error) {
-		return newStack(c.main, c.CalledStackAddr(), c.call.stack, c.call.config.TargetConfig()), nil
+		return newStack(c.main, c.CalledStackAddr(), c.call.stack, c.call.config.TargetConfig(), c.call.GetExternalRemovedBlocks(), c.mode, c.deferred), nil
 	})
 	if err != nil {
 		// we don't have cycles in here, and we don't return an error so this
@@ -108,109 +113,8 @@ func (c *StackCallInstance) InputVariableValues(ctx context.Context, phase EvalP
 // child stack input variable declaration, as part of preparing the individual
 // attributes of the result for their appearance in downstream expressions.
 func (c *StackCallInstance) CheckInputVariableValues(ctx context.Context, phase EvalPhase) (cty.Value, tfdiags.Diagnostics) {
-	return doOnceWithDiags(ctx, c.tracingName()+" inputs", c.inputVariableValues.For(phase), func(ctx context.Context) (cty.Value, tfdiags.Diagnostics) {
-		var diags tfdiags.Diagnostics
-		calledStack := c.Stack(ctx, phase)
-		wantTy, defs := calledStack.InputsType()
-		decl := c.call.config.config
-
-		v := cty.EmptyObjectVal
-		expr := decl.Inputs
-		rng := decl.DeclRange
-		var hclCtx *hcl.EvalContext
-		if expr != nil {
-			result, moreDiags := EvalExprAndEvalContext(ctx, expr, phase, c)
-			diags = diags.Append(moreDiags)
-			if moreDiags.HasErrors() {
-				return cty.DynamicVal, diags
-			}
-			expr = result.Expression
-			hclCtx = result.EvalContext
-			v = result.Value
-		}
-
-		v = defs.Apply(v)
-		v, err := convert.Convert(v, wantTy)
-		if err != nil {
-			// A conversion failure here could either be caused by an author-provided
-			// expression that's invalid or by the author omitting the argument
-			// altogether when there's at least one required attribute, so we'll
-			// return slightly different messages in each case.
-			if expr != nil {
-				diags = diags.Append(&hcl.Diagnostic{
-					Severity:    hcl.DiagError,
-					Summary:     "Invalid inputs for embedded stack",
-					Detail:      fmt.Sprintf("Invalid input variable definition object: %s.", tfdiags.FormatError(err)),
-					Subject:     rng.ToHCL().Ptr(),
-					Expression:  expr,
-					EvalContext: hclCtx,
-				})
-			} else {
-				diags = diags.Append(&hcl.Diagnostic{
-					Severity: hcl.DiagError,
-					Summary:  "Missing required inputs for embedded stack",
-					Detail:   fmt.Sprintf("Must provide \"inputs\" argument to define the embedded stack's input variables: %s.", tfdiags.FormatError(err)),
-					Subject:  rng.ToHCL().Ptr(),
-				})
-			}
-			return cty.DynamicVal, diags
-		}
-
-		if v.IsKnown() && !v.IsNull() {
-			var markDiags tfdiags.Diagnostics
-			for varAddr, variable := range calledStack.InputVariables() {
-				varVal := v.GetAttr(varAddr.Name)
-				varDecl := variable.config.config
-
-				if !varDecl.Ephemeral {
-					// If the variable isn't declared as being ephemeral then we
-					// cannot allow ephemeral values to be assigned to it.
-					_, markses := varVal.UnmarkDeepWithPaths()
-					ephemeralPaths, _ := marks.PathsWithMark(markses, marks.Ephemeral)
-					for _, path := range ephemeralPaths {
-						if len(path) == 0 {
-							// The entire value is ephemeral, then.
-							markDiags = markDiags.Append(&hcl.Diagnostic{
-								Severity:    hcl.DiagError,
-								Summary:     "Ephemeral value not allowed",
-								Detail:      fmt.Sprintf("The input variable %q does not accept ephemeral values.", varAddr.Name),
-								Subject:     rng.ToHCL().Ptr(),
-								Expression:  expr,
-								EvalContext: hclCtx,
-								Extra:       diagnosticCausedByEphemeral(true),
-							})
-						} else {
-							// Something nested inside is ephemeral, so we'll be
-							// more specific.
-							markDiags = markDiags.Append(&hcl.Diagnostic{
-								Severity: hcl.DiagError,
-								Summary:  "Ephemeral value not allowed",
-								Detail: fmt.Sprintf(
-									"The input variable %q does not accept ephemeral values, so the value for %s is not compatible.",
-									varAddr.Name, tfdiags.FormatCtyPath(path),
-								),
-								Subject:     rng.ToHCL().Ptr(),
-								Expression:  expr,
-								EvalContext: hclCtx,
-								Extra:       diagnosticCausedByEphemeral(true),
-							})
-						}
-					}
-				}
-			}
-			diags = diags.Append(markDiags)
-			if markDiags.HasErrors() {
-				// If we have an ephemeral value in a place where there shouldn't
-				// be one then we'll return an entirely-unknown value to make sure
-				// that downstreams that aren't checking the errors can't leak the
-				// value into somewhere it ought not to be. We'll still preserve
-				// the type constraint so that we can do type checking downstream.
-				return cty.UnknownVal(v.Type()), diags
-			}
-		}
-
-		return v, diags
-	})
+	return doOnceWithDiags(ctx, c.tracingName()+" inputs", c.inputVariableValues.For(phase),
+		validateStackCallInstanceInputsFn(c.Stack(ctx, phase), c.call.config.config.Inputs, c.call.config.config.DeclRange.ToHCL().Ptr(), c, phase))
 }
 
 // ResolveExpressionReference implements ExpressionScope for the arguments
@@ -262,3 +166,105 @@ func (c *StackCallInstance) CheckApply(ctx context.Context) ([]stackstate.Applie
 func (c *StackCallInstance) tracingName() string {
 	return fmt.Sprintf("%s call", c.CalledStackAddr())
 }
+
+func validateStackCallInstanceInputsFn(stack *Stack, expr hcl.Expression, rng *hcl.Range, scope ExpressionScope, phase EvalPhase) func(ctx context.Context) (cty.Value, tfdiags.Diagnostics) {
+	return func(ctx context.Context) (cty.Value, tfdiags.Diagnostics) {
+		var diags tfdiags.Diagnostics
+		wantTy, defs := stack.InputsType()
+
+		v := cty.EmptyObjectVal
+		var hclCtx *hcl.EvalContext
+		if expr != nil {
+			result, moreDiags := EvalExprAndEvalContext(ctx, expr, phase, scope)
+			diags = diags.Append(moreDiags)
+			if moreDiags.HasErrors() {
+				return cty.DynamicVal, diags
+			}
+			expr = result.Expression
+			hclCtx = result.EvalContext
+			v = result.Value
+		}
+
+		v = defs.Apply(v)
+		v, err := convert.Convert(v, wantTy)
+		if err != nil {
+			// A conversion failure here could either be caused by an author-provided
+			// expression that's invalid or by the author omitting the argument
+			// altogether when there's at least one required attribute, so we'll
+			// return slightly different messages in each case.
+			if expr != nil {
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity:    hcl.DiagError,
+					Summary:     "Invalid inputs for embedded stack",
+					Detail:      fmt.Sprintf("Invalid input variable definition object: %s.", tfdiags.FormatError(err)),
+					Subject:     rng,
+					Expression:  expr,
+					EvalContext: hclCtx,
+				})
+			} else {
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Missing required inputs for embedded stack",
+					Detail:   fmt.Sprintf("Must provide \"inputs\" argument to define the embedded stack's input variables: %s.", tfdiags.FormatError(err)),
+					Subject:  rng,
+				})
+			}
+			return cty.DynamicVal, diags
+		}
+
+		if v.IsKnown() && !v.IsNull() {
+			var markDiags tfdiags.Diagnostics
+			for varAddr, variable := range stack.InputVariables() {
+				varVal := v.GetAttr(varAddr.Name)
+				varDecl := variable.config.config
+
+				if !varDecl.Ephemeral {
+					// If the variable isn't declared as being ephemeral then we
+					// cannot allow ephemeral values to be assigned to it.
+					_, markses := varVal.UnmarkDeepWithPaths()
+					ephemeralPaths, _ := marks.PathsWithMark(markses, marks.Ephemeral)
+					for _, path := range ephemeralPaths {
+						if len(path) == 0 {
+							// The entire value is ephemeral, then.
+							markDiags = markDiags.Append(&hcl.Diagnostic{
+								Severity:    hcl.DiagError,
+								Summary:     "Ephemeral value not allowed",
+								Detail:      fmt.Sprintf("The input variable %q does not accept ephemeral values.", varAddr.Name),
+								Subject:     rng,
+								Expression:  expr,
+								EvalContext: hclCtx,
+								Extra:       diagnosticCausedByEphemeral(true),
+							})
+						} else {
+							// Something nested inside is ephemeral, so we'll be
+							// more specific.
+							markDiags = markDiags.Append(&hcl.Diagnostic{
+								Severity: hcl.DiagError,
+								Summary:  "Ephemeral value not allowed",
+								Detail: fmt.Sprintf(
+									"The input variable %q does not accept ephemeral values, so the value for %s is not compatible.",
+									varAddr.Name, tfdiags.FormatCtyPath(path),
+								),
+								Subject:     rng,
+								Expression:  expr,
+								EvalContext: hclCtx,
+								Extra:       diagnosticCausedByEphemeral(true),
+							})
+						}
+					}
+				}
+			}
+			diags = diags.Append(markDiags)
+			if markDiags.HasErrors() {
+				// If we have an ephemeral value in a place where there shouldn't
+				// be one then we'll return an entirely-unknown value to make sure
+				// that downstreams that aren't checking the errors can't leak the
+				// value into somewhere it ought not to be. We'll still preserve
+				// the type constraint so that we can do type checking downstream.
+				return cty.UnknownVal(v.Type()), diags
+			}
+		}
+
+		return v, diags
+	}
+}
