@@ -4,8 +4,10 @@
 package statemgr
 
 import (
+	"context"
+
+	"github.com/hashicorp/terraform/internal/schemarepo"
 	"github.com/hashicorp/terraform/internal/states"
-	"github.com/hashicorp/terraform/internal/terraform"
 )
 
 // LockDisabled implements State and Locker but disables state locking.
@@ -21,8 +23,8 @@ func (s *LockDisabled) State() *states.State {
 	return s.Inner.State()
 }
 
-func (s *LockDisabled) GetRootOutputValues() (map[string]*states.OutputValue, error) {
-	return s.Inner.GetRootOutputValues()
+func (s *LockDisabled) GetRootOutputValues(ctx context.Context) (map[string]*states.OutputValue, error) {
+	return s.Inner.GetRootOutputValues(ctx)
 }
 
 func (s *LockDisabled) WriteState(v *states.State) error {
@@ -33,7 +35,7 @@ func (s *LockDisabled) RefreshState() error {
 	return s.Inner.RefreshState()
 }
 
-func (s *LockDisabled) PersistState(schemas *terraform.Schemas) error {
+func (s *LockDisabled) PersistState(schemas *schemarepo.Schemas) error {
 	return s.Inner.PersistState(schemas)
 }
 
