@@ -48,7 +48,10 @@ func TestFull(t *testing.T, s Full) {
 	current := s.State()
 
 	// Write a new state and verify that we have it
-	current.RootModule().SetOutputValue("bar", cty.StringVal("baz"), false)
+	current.SetOutputValue(
+		addrs.OutputValue{Name: "bar"}.Absolute(addrs.RootModuleInstance),
+		cty.StringVal("baz"), false,
+	)
 
 	if err := s.WriteState(current); err != nil {
 		t.Fatalf("err: %s", err)
@@ -101,9 +104,11 @@ func TestFull(t *testing.T, s Full) {
 
 	// Change the serial
 	current = current.DeepCopy()
-	current.EnsureModule(addrs.RootModuleInstance).SetOutputValue(
-		"serialCheck", cty.StringVal("true"), false,
+	current.SetOutputValue(
+		addrs.OutputValue{Name: "serialCheck"}.Absolute(addrs.RootModuleInstance),
+		cty.StringVal("true"), false,
 	)
+
 	if err := s.WriteState(current); err != nil {
 		t.Fatalf("err: %s", err)
 	}
@@ -159,8 +164,14 @@ func TestFullInitialState() *states.State {
 	}
 	childMod.SetResourceProvider(rAddr, providerAddr)
 
-	state.RootModule().SetOutputValue("sensitive_output", cty.StringVal("it's a secret"), true)
-	state.RootModule().SetOutputValue("nonsensitive_output", cty.StringVal("hello, world!"), false)
+	state.SetOutputValue(
+		addrs.OutputValue{Name: "sensitive_output"}.Absolute(addrs.RootModuleInstance),
+		cty.StringVal("it's a secret"), true,
+	)
+	state.SetOutputValue(
+		addrs.OutputValue{Name: "nonsensitive_output"}.Absolute(addrs.RootModuleInstance),
+		cty.StringVal("hello, world!"), false,
+	)
 
 	return state
 }
