@@ -58,6 +58,11 @@ type MockEvalContext struct {
 	ProviderSchemaSchema providers.ProviderSchema
 	ProviderSchemaError  error
 
+	ResourceIdentitySchemasCalled  bool
+	ResourceIdentitySchemasAddr    addrs.AbsProviderConfig
+	ResourceIdentitySchemasSchemas providers.ResourceIdentitySchemas
+	ResourceIdentitySchemasError   error
+
 	CloseProviderCalled   bool
 	CloseProviderAddr     addrs.AbsProviderConfig
 	CloseProviderProvider providers.Interface
@@ -209,6 +214,12 @@ func (c *MockEvalContext) ProviderSchema(addr addrs.AbsProviderConfig) (provider
 	return c.ProviderSchemaSchema, c.ProviderSchemaError
 }
 
+func (c *MockEvalContext) ResourceIdentitySchemas(addr addrs.AbsProviderConfig) (providers.ResourceIdentitySchemas, error) {
+	c.ResourceIdentitySchemasCalled = true
+	c.ResourceIdentitySchemasAddr = addr
+	return c.ResourceIdentitySchemasSchemas, c.ProviderSchemaError
+}
+
 func (c *MockEvalContext) CloseProvider(addr addrs.AbsProviderConfig) error {
 	c.CloseProviderCalled = true
 	c.CloseProviderAddr = addr
