@@ -76,6 +76,11 @@ type Evaluator struct {
 	// ensures they can be safely accessed and modified concurrently.
 	Changes *plans.ChangesSync
 
+	// FunctionResults carries forward the global cache of function results to
+	// be used when building out all the builtin functions returned in the
+	// Scope.
+	FunctionResults *lang.FunctionResults
+
 	PlanTimestamp time.Time
 }
 
@@ -87,14 +92,15 @@ type Evaluator struct {
 // address.
 func (e *Evaluator) Scope(data lang.Data, self addrs.Referenceable, source addrs.Referenceable, extFuncs lang.ExternalFuncs) *lang.Scope {
 	return &lang.Scope{
-		Data:          data,
-		ParseRef:      addrs.ParseRef,
-		SelfAddr:      self,
-		SourceAddr:    source,
-		PureOnly:      e.Operation != walkApply && e.Operation != walkDestroy && e.Operation != walkEval,
-		BaseDir:       ".", // Always current working directory for now.
-		PlanTimestamp: e.PlanTimestamp,
-		ExternalFuncs: extFuncs,
+		Data:            data,
+		ParseRef:        addrs.ParseRef,
+		SelfAddr:        self,
+		SourceAddr:      source,
+		PureOnly:        e.Operation != walkApply && e.Operation != walkDestroy && e.Operation != walkEval,
+		BaseDir:         ".", // Always current working directory for now.
+		PlanTimestamp:   e.PlanTimestamp,
+		ExternalFuncs:   extFuncs,
+		FunctionResults: e.FunctionResults,
 	}
 }
 
@@ -336,8 +342,11 @@ func (d *evaluationStateData) GetLocalValue(addr addrs.LocalValue, rng tfdiags.S
 		return cty.DynamicVal, diags
 	}
 
-	val := d.Evaluator.NamedValues.GetLocalValue(addr.Absolute(d.ModulePath))
-	return val, diags
+	if target := addr.Absolute(d.ModulePath); d.Evaluator.NamedValues.HasLocalValue(target) {
+		return d.Evaluator.NamedValues.GetLocalValue(addr.Absolute(d.ModulePath)), diags
+	}
+
+	return cty.DynamicVal, diags
 }
 
 func (d *evaluationStateData) GetModule(addr addrs.ModuleCall, rng tfdiags.SourceRange) (cty.Value, tfdiags.Diagnostics) {
@@ -424,7 +433,7 @@ func (d *evaluationStateData) GetModule(addr addrs.ModuleCall, rng tfdiags.Sourc
 		namedVals := d.Evaluator.NamedValues
 		moduleInstAddr := absAddr.Instance(instKey)
 		attrs := make(map[string]cty.Value, len(outputConfigs))
-		for name := range outputConfigs {
+		for name, cfg := range outputConfigs {
 			outputAddr := moduleInstAddr.OutputValue(name)
 
 			// Although we do typically expect the graph dependencies to
@@ -440,6 +449,9 @@ func (d *evaluationStateData) GetModule(addr addrs.ModuleCall, rng tfdiags.Sourc
 				continue
 			}
 			outputVal := namedVals.GetOutputValue(outputAddr)
+			if cfg.Sensitive {
+				outputVal = outputVal.Mark(marks.Sensitive)
+			}
 			attrs[name] = outputVal
 		}
 
@@ -532,6 +544,21 @@ func (d *evaluationStateData) GetResource(addr addrs.Resource, rng tfdiags.Sourc
 	// result for _all_ of its work, rather than continuing to duplicate a bunch
 	// of the logic we've tried to encapsulate over ther already.
 	if d.Operation == walkPlan || d.Operation == walkApply {
+		if !d.Evaluator.Instances.ResourceInstanceExpanded(addr.Absolute(moduleAddr)) {
+			// Then we've asked for a resource that hasn't been evaluated yet.
+			// This means that either something has gone wrong in the graph or
+			// the console or test command has an errored plan and is attempting
+			// to load an invalid resource from it.
+
+			unknownVal := cty.DynamicVal
+
+			// If an ephemeral resource is deferred we need to mark the returned unknown value as ephemeral
+			if addr.Mode == addrs.EphemeralResourceMode {
+				unknownVal = unknownVal.Mark(marks.Ephemeral)
+			}
+			return unknownVal, diags
+		}
+
 		if _, _, hasUnknownKeys := d.Evaluator.Instances.ResourceInstanceKeys(addr.Absolute(moduleAddr)); hasUnknownKeys {
 			// There really isn't anything interesting we can do in this situation,
 			// because it means we have an unknown for_each/count, in which case
@@ -569,7 +596,8 @@ func (d *evaluationStateData) GetResource(addr addrs.Resource, rng tfdiags.Sourc
 	}
 	ty := schema.Body.ImpliedType()
 
-	if addr.Mode == addrs.EphemeralResourceMode {
+	switch addr.Mode {
+	case addrs.EphemeralResourceMode:
 		// FIXME: This does not yet work with deferrals, and it would be nice to
 		// find some way to refactor this so that the following code is not so
 		// tethered to the current implementation details. Instead we should
@@ -578,6 +606,10 @@ func (d *evaluationStateData) GetResource(addr addrs.Resource, rng tfdiags.Sourc
 		// then retrieving the value for each instance to assemble into the
 		// result, using some per-resource-mode logic maintained elsewhere.
 		return d.getEphemeralResource(addr, rng)
+	case addrs.ListResourceMode:
+		return d.getListResource(config, rng)
+	default:
+		// continue with the rest of the function
 	}
 
 	rs := d.Evaluator.State.Resource(addr.Absolute(d.ModulePath))
@@ -647,6 +679,16 @@ func (d *evaluationStateData) GetResource(addr addrs.Resource, rng tfdiags.Sourc
 		instances[key] = value
 	}
 
+	// Proactively read out all the resource changes before iteration. Not only
+	// does GetResourceInstanceChange have to iterate over all instances
+	// internally causing an n^2 lookup, but Changes is also a major point of
+	// lock contention.
+	resChanges := d.Evaluator.Changes.GetChangesForConfigResource(addr.InModule(moduleConfig.Path))
+	instChanges := addrs.MakeMap[addrs.AbsResourceInstance, *plans.ResourceInstanceChange]()
+	for _, ch := range resChanges {
+		instChanges.Put(ch.Addr, ch)
+	}
+
 	// Decode all instances in the current state
 	pendingDestroy := d.Operation == walkDestroy
 	for key, is := range rs.Instances {
@@ -664,7 +706,7 @@ func (d *evaluationStateData) GetResource(addr addrs.Resource, rng tfdiags.Sourc
 		}
 
 		instAddr := addr.Instance(key).Absolute(d.ModulePath)
-		change := d.Evaluator.Changes.GetResourceInstanceChange(instAddr, addrs.NotDeposed)
+		change := instChanges.Get(instAddr)
 		if change != nil {
 			// Don't take any resources that are yet to be deleted into account.
 			// If the referenced resource is CreateBeforeDestroy, then orphaned
@@ -787,6 +829,117 @@ func (d *evaluationStateData) GetResource(addr addrs.Resource, rng tfdiags.Sourc
 	return ret, diags
 }
 
+func (d *evaluationStateData) getListResource(config *configs.Resource, rng tfdiags.SourceRange) (cty.Value, tfdiags.Diagnostics) {
+	var diags tfdiags.Diagnostics
+	switch d.Operation {
+	case walkValidate:
+		return cty.DynamicVal, diags
+	case walkPlan:
+		// continue
+	default:
+		return cty.DynamicVal, diags.Append(&hcl.Diagnostic{
+			Severity: hcl.DiagError,
+			Summary:  `Unsupported operation`,
+			Detail:   fmt.Sprintf("List resources are not supported in %s operations.", d.Operation),
+			Subject:  rng.ToHCL().Ptr(),
+		})
+	}
+
+	lAddr := config.Addr()
+	mAddr := addrs.Resource{
+		Mode: addrs.ManagedResourceMode,
+		Type: lAddr.Type,
+		Name: lAddr.Name,
+	}
+	resourceSchema := d.getResourceSchema(mAddr, config.Provider)
+	if resourceSchema.Body == nil {
+		// This shouldn't happen, since validation before we get here should've
+		// taken care of it, but we'll show a reasonable error message anyway.
+		diags = diags.Append(&hcl.Diagnostic{
+			Severity: hcl.DiagError,
+			Summary:  `Missing resource type schema`,
+			Detail:   fmt.Sprintf("No schema is available for %s in %s. This is a bug in Terraform and should be reported.", lAddr, config.Provider),
+			Subject:  rng.ToHCL().Ptr(),
+		})
+		return cty.DynamicVal, diags
+	}
+	resourceType := resourceSchema.Body.ImpliedType()
+	queries := d.Evaluator.Changes.GetQueryInstancesForAbsResource(lAddr.Absolute(d.ModulePath))
+
+	if len(queries) == 0 {
+		// Since we know there are no instances, return an empty container of the expected type.
+		switch {
+		case config.Count != nil:
+			return cty.EmptyTupleVal, diags
+		case config.ForEach != nil:
+			return cty.EmptyObjectVal, diags
+		default:
+			return cty.DynamicVal, diags
+		}
+	}
+
+	var ret cty.Value
+	switch {
+	case config.Count != nil:
+		// figure out what the last index we have is
+		length := -1
+		for _, inst := range queries {
+			if intKey, ok := inst.Addr.Resource.Key.(addrs.IntKey); ok {
+				length = max(int(intKey)+1, length)
+			}
+		}
+
+		if length > 0 {
+			vals := make([]cty.Value, length)
+			for _, inst := range queries {
+				key := inst.Addr.Resource.Key
+				if intKey, ok := key.(addrs.IntKey); ok {
+					vals[int(intKey)] = inst.Results.Value
+				}
+			}
+
+			// Insert unknown values where there are any missing instances
+			for i, v := range vals {
+				if v == cty.NilVal {
+					vals[i] = cty.UnknownVal(resourceType)
+				}
+			}
+			ret = cty.TupleVal(vals)
+		} else {
+			ret = cty.EmptyTupleVal
+		}
+	case config.ForEach != nil:
+		vals := make(map[string]cty.Value)
+		for _, inst := range queries {
+			key := inst.Addr.Resource.Key
+			if strKey, ok := key.(addrs.StringKey); ok {
+				vals[string(strKey)] = inst.Results.Value
+			}
+		}
+
+		if len(vals) > 0 {
+			// We use an object rather than a map here because resource schemas
+			// may include dynamically-typed attributes, which will then cause
+			// each instance to potentially have a different runtime type even
+			// though they all conform to the static schema.
+			ret = cty.ObjectVal(vals)
+		} else {
+			ret = cty.EmptyObjectVal
+		}
+	default:
+		if len(queries) <= 0 {
+			// if the instance is missing, insert an empty tuple
+			ret = cty.ObjectVal(map[string]cty.Value{
+				"data": cty.EmptyTupleVal,
+			})
+		} else {
+			ret = queries[0].Results.Value
+		}
+	}
+
+	return ret, diags
+}
+
 func (d *evaluationStateData) getEphemeralResource(addr addrs.Resource, rng tfdiags.SourceRange) (cty.Value, tfdiags.Diagnostics) {
 	var diags tfdiags.Diagnostics
 
