@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package terraform
 
 import (
@@ -42,7 +45,6 @@ func TestBasicGraphBuilder_validate(t *testing.T) {
 			&testBasicGraphBuilderTransform{1},
 			&testBasicGraphBuilderTransform{2},
 		},
-		Validate: true,
 	}
 
 	_, err := b.Build(addrs.RootModuleInstance)
@@ -51,21 +53,6 @@ func TestBasicGraphBuilder_validate(t *testing.T) {
 	}
 }
 
-func TestBasicGraphBuilder_validateOff(t *testing.T) {
-	b := &BasicGraphBuilder{
-		Steps: []GraphTransformer{
-			&testBasicGraphBuilderTransform{1},
-			&testBasicGraphBuilderTransform{2},
-		},
-		Validate: false,
-	}
-
-	_, err := b.Build(addrs.RootModuleInstance)
-	if err != nil {
-		t.Fatalf("expected no error, got: %s", err)
-	}
-}
-
 type testBasicGraphBuilderTransform struct {
 	V dag.Vertex
 }
