@@ -14,6 +14,7 @@ import (
 	"github.com/hashicorp/terraform/internal/configs"
 	"github.com/hashicorp/terraform/internal/configs/configschema"
 	"github.com/hashicorp/terraform/internal/instances"
+	"github.com/hashicorp/terraform/internal/lang"
 	"github.com/hashicorp/terraform/internal/moduletest/mocking"
 	"github.com/hashicorp/terraform/internal/namedvals"
 	"github.com/hashicorp/terraform/internal/plans"
@@ -58,17 +59,17 @@ type ContextGraphWalker struct {
 	// is in progress.
 	NonFatalDiagnostics tfdiags.Diagnostics
 
-	once                sync.Once
-	contexts            collections.Map[evalContextScope, *BuiltinEvalContext]
-	contextLock         sync.Mutex
-	providerCache       map[string]providers.Interface
-	providerFuncCache   map[string]providers.Interface
-	providerFuncResults *providers.FunctionResults
-	providerSchemas     map[string]providers.ProviderSchema
-	providerLock        sync.Mutex
-	provisionerCache    map[string]provisioners.Interface
-	provisionerSchemas  map[string]*configschema.Block
-	provisionerLock     sync.Mutex
+	once               sync.Once
+	contexts           collections.Map[evalContextScope, *BuiltinEvalContext]
+	contextLock        sync.Mutex
+	providerCache      map[string]providers.Interface
+	providerFuncCache  map[string]providers.Interface
+	functionResults    *lang.FunctionResults
+	providerSchemas    map[string]providers.ProviderSchema
+	providerLock       sync.Mutex
+	provisionerCache   map[string]provisioners.Interface
+	provisionerSchemas map[string]*configschema.Block
+	provisionerLock    sync.Mutex
 }
 
 var _ GraphWalker = (*ContextGraphWalker)(nil)
@@ -111,6 +112,7 @@ func (w *ContextGraphWalker) EvalContext() EvalContext {
 		NamedValues:        w.NamedValues,
 		Deferrals:          w.Deferrals,
 		PlanTimestamp:      w.PlanTimestamp,
+		FunctionResults:    w.functionResults,
 	}
 
 	ctx := &BuiltinEvalContext{
@@ -124,7 +126,7 @@ func (w *ContextGraphWalker) EvalContext() EvalContext {
 		MoveResultsValue:        w.MoveResults,
 		ProviderCache:           w.providerCache,
 		ProviderFuncCache:       w.providerFuncCache,
-		ProviderFuncResults:     w.providerFuncResults,
+		FunctionResults:         w.functionResults,
 		ProviderInputConfig:     w.Context.providerInputConfig,
 		ProviderLock:            &w.providerLock,
 		ProvisionerCache:        w.provisionerCache,
