@@ -7,9 +7,9 @@
 package tools
 
 import (
-	_ "github.com/golang/mock/mockgen"
 	_ "github.com/mitchellh/gox"
 	_ "github.com/nishanths/exhaustive"
+	_ "go.uber.org/mock/mockgen"
 	_ "golang.org/x/tools/cmd/cover"
 	_ "golang.org/x/tools/cmd/stringer"
 	_ "google.golang.org/grpc/cmd/protoc-gen-go-grpc"
